@@ -16,18 +16,28 @@
 bool str2num(const SQChar *s,SQObjectPtr &res)
 {
 	SQChar *end;
-	if(scstrstr(s,_SC("."))){
+	const SQChar *e = s;
+	SQBool isfloat = SQFalse;
+	SQChar c;
+	while((c = *e) != _SC('\0'))
+	{
+		if(c == _SC('.') || c == _SC('E')|| c == _SC('e')) { //e and E is for scientific notation
+			isfloat = SQTrue;
+			break;
+		}
+		e++;
+	}
+	if(isfloat){
 		SQFloat r = SQFloat(scstrtod(s,&end));
 		if(s == end) return false;
 		res = r;
-		return true;
 	}
 	else{
 		SQInteger r = SQInteger(scstrtol(s,&end,10));
 		if(s == end) return false;
 		res = r;
-		return true;
 	}
+	return true;
 }
 
 static SQInteger base_dummy(HSQUIRRELVM v)
@@ -41,6 +51,11 @@ static SQInteger base_collectgarbage(HSQUIRRELVM v)
 	sq_pushinteger(v, sq_collectgarbage(v));
 	return 1;
 }
+static SQInteger base_resurectureachable(HSQUIRRELVM v)
+{
+	sq_resurrectunreachable(v);
+	return 1;
+}
 #endif
 
 static SQInteger base_getroottable(HSQUIRRELVM v)
@@ -58,7 +73,7 @@ static SQInteger base_getconsttable(HSQUIRRELVM v)
 
 static SQInteger base_setroottable(HSQUIRRELVM v)
 {
-	SQObjectPtr &o=stack_get(v,2);
+	SQObjectPtr o = v->_roottable;
 	if(SQ_FAILED(sq_setroottable(v))) return SQ_ERROR;
 	v->Push(o);
 	return 1;
@@ -66,7 +81,7 @@ static SQInteger base_setroottable(HSQUIRRELVM v)
 
 static SQInteger base_setconsttable(HSQUIRRELVM v)
 {
-	SQObjectPtr &o=stack_get(v,2);
+	SQObjectPtr o = _ss(v)->_consts;
 	if(SQ_FAILED(sq_setconsttable(v))) return SQ_ERROR;
 	v->Push(o);
 	return 1;
@@ -87,17 +102,17 @@ static SQInteger base_setdebughook(HSQUIRRELVM v)
 static SQInteger base_enabledebuginfo(HSQUIRRELVM v)
 {
 	SQObjectPtr &o=stack_get(v,2);
-	sq_enabledebuginfo(v,(type(o) != OT_NULL)?1:0);
+	
+	sq_enabledebuginfo(v,SQVM::IsFalse(o)?SQFalse:SQTrue);
 	return 0;
 }
 
-static SQInteger base_getstackinfos(HSQUIRRELVM v)
+static SQInteger __getcallstackinfos(HSQUIRRELVM v,SQInteger level)
 {
-	SQInteger level;
 	SQStackInfos si;
 	SQInteger seq = 0;
 	const SQChar *name = NULL;
-	sq_getinteger(v, -1, &level);
+	
 	if (SQ_SUCCEEDED(sq_stackinfos(v, level, &si)))
 	{
 		const SQChar *fn = _SC("unknown");
@@ -107,33 +122,39 @@ static SQInteger base_getstackinfos(HSQUIRRELVM v)
 		sq_newtable(v);
 		sq_pushstring(v, _SC("func"), -1);
 		sq_pushstring(v, fn, -1);
-		sq_createslot(v, -3);
+		sq_newslot(v, -3, SQFalse);
 		sq_pushstring(v, _SC("src"), -1);
 		sq_pushstring(v, src, -1);
-		sq_createslot(v, -3);
+		sq_newslot(v, -3, SQFalse);
 		sq_pushstring(v, _SC("line"), -1);
 		sq_pushinteger(v, si.line);
-		sq_createslot(v, -3);
+		sq_newslot(v, -3, SQFalse);
 		sq_pushstring(v, _SC("locals"), -1);
 		sq_newtable(v);
 		seq=0;
 		while ((name = sq_getlocal(v, level, seq))) {
 			sq_pushstring(v, name, -1);
 			sq_push(v, -2);
-			sq_createslot(v, -4);
+			sq_newslot(v, -4, SQFalse);
 			sq_pop(v, 1);
 			seq++;
 		}
-		sq_createslot(v, -3);
+		sq_newslot(v, -3, SQFalse);
 		return 1;
 	}
 
 	return 0;
 }
+static SQInteger base_getstackinfos(HSQUIRRELVM v)
+{
+	SQInteger level;
+	sq_getinteger(v, -1, &level);
+	return __getcallstackinfos(v,level);
+}
 
 static SQInteger base_assert(HSQUIRRELVM v)
 {
-	if(v->IsFalse(stack_get(v,2))){
+	if(SQVM::IsFalse(stack_get(v,2))){
 		return sq_throwerror(v,_SC("assertion failed"));
 	}
 	return 0;
@@ -164,10 +185,27 @@ static SQInteger get_slice_params(HSQUIRRELVM v,SQInteger &sidx,SQInteger &eidx,
 static SQInteger base_print(HSQUIRRELVM v)
 {
 	const SQChar *str;
-	sq_tostring(v,2);
-	sq_getstring(v,-1,&str);
-	if(_ss(v)->_printfunc) _ss(v)->_printfunc(v,_SC("%s"),str);
-	return 0;
+	if(SQ_SUCCEEDED(sq_tostring(v,2)))
+	{
+ 		if(SQ_SUCCEEDED(sq_getstring(v,-1,&str))) {
+			if(_ss(v)->_printfunc) _ss(v)->_printfunc(v,_SC("%s"),str);
+			return 0;
+		}
+	}
+	return SQ_ERROR;
+}
+
+static SQInteger base_error(HSQUIRRELVM v)
+{
+	const SQChar *str;
+	if(SQ_SUCCEEDED(sq_tostring(v,2)))
+	{
+ 		if(SQ_SUCCEEDED(sq_getstring(v,-1,&str))) {
+			if(_ss(v)->_errorfunc) _ss(v)->_errorfunc(v,_SC("%s"),str);
+			return 0;
+		}
+	}
+	return SQ_ERROR;
 }
 
 static SQInteger base_compilestring(HSQUIRRELVM v)
@@ -189,7 +227,7 @@ static SQInteger base_compilestring(HSQUIRRELVM v)
 static SQInteger base_newthread(HSQUIRRELVM v)
 {
 	SQObjectPtr &func = stack_get(v,2);
-	SQInteger stksize = (_funcproto(_closure(func)->_function)->_stacksize << 1) +2;
+	SQInteger stksize = (_closure(func)->_function->_stacksize << 1) +2;
 	HSQUIRRELVM newv = sq_newthread(v, (stksize < MIN_STACK_OVERHEAD + 2)? MIN_STACK_OVERHEAD + 2 : stksize);
 	sq_move(newv,v,-2);
 	return 1;
@@ -222,6 +260,16 @@ static SQInteger base_type(HSQUIRRELVM v)
 	return 1;
 }
 
+static SQInteger base_callee(HSQUIRRELVM v)
+{
+	if(v->_callsstacksize > 1)
+	{
+		v->Push(v->_callsstack[v->_callsstacksize - 2]._closure);
+		return 1;
+	}
+	return sq_throwerror(v,_SC("no closure in the calls stack"));
+}
+
 static SQRegFunction base_funcs[]={
 	//generic
 	{_SC("seterrorhandler"),base_seterrorhandler,2, NULL},
@@ -234,14 +282,17 @@ static SQRegFunction base_funcs[]={
 	{_SC("setconsttable"),base_setconsttable,2, NULL},
 	{_SC("assert"),base_assert,2, NULL},
 	{_SC("print"),base_print,2, NULL},
+	{_SC("error"),base_error,2, NULL},
 	{_SC("compilestring"),base_compilestring,-2, _SC(".ss")},
 	{_SC("newthread"),base_newthread,2, _SC(".c")},
 	{_SC("suspend"),base_suspend,-1, NULL},
 	{_SC("array"),base_array,-2, _SC(".n")},
 	{_SC("type"),base_type,2, NULL},
+	{_SC("callee"),base_callee,0,NULL},
 	{_SC("dummy"),base_dummy,0,NULL},
 #ifndef NO_GARBAGE_COLLECTOR
-	{_SC("collectgarbage"),base_collectgarbage,1, _SC("t")},
+	{_SC("collectgarbage"),base_collectgarbage,0, NULL},
+	{_SC("resurrectunreachable"),base_resurectureachable,0, NULL},
 #endif
 	{0,0}
 };
@@ -255,21 +306,25 @@ void sq_base_register(HSQUIRRELVM v)
 		sq_newclosure(v,base_funcs[i].f,0);
 		sq_setnativeclosurename(v,-1,base_funcs[i].name);
 		sq_setparamscheck(v,base_funcs[i].nparamscheck,base_funcs[i].typemask);
-		sq_createslot(v,-3);
+		sq_newslot(v,-3, SQFalse);
 		i++;
 	}
+	
+	sq_pushstring(v,_SC("_versionnumber_"),-1);
+	sq_pushinteger(v,SQUIRREL_VERSION_NUMBER);
+	sq_newslot(v,-3, SQFalse);
 	sq_pushstring(v,_SC("_version_"),-1);
 	sq_pushstring(v,SQUIRREL_VERSION,-1);
-	sq_createslot(v,-3);
+	sq_newslot(v,-3, SQFalse);
 	sq_pushstring(v,_SC("_charsize_"),-1);
 	sq_pushinteger(v,sizeof(SQChar));
-	sq_createslot(v,-3);
+	sq_newslot(v,-3, SQFalse);
 	sq_pushstring(v,_SC("_intsize_"),-1);
 	sq_pushinteger(v,sizeof(SQInteger));
-	sq_createslot(v,-3);
+	sq_newslot(v,-3, SQFalse);
 	sq_pushstring(v,_SC("_floatsize_"),-1);
 	sq_pushinteger(v,sizeof(SQFloat));
-	sq_createslot(v,-3);
+	sq_newslot(v,-3, SQFalse);
 	sq_pop(v,1);
 }
 
@@ -298,7 +353,7 @@ static SQInteger default_delegate_tofloat(HSQUIRRELVM v)
 		v->Push(SQObjectPtr((SQFloat)(_integer(o)?1:0)));
 		break;
 	default:
-		v->Push(_null_);
+		v->PushNull();
 		break;
 	}
 	return 1;
@@ -323,7 +378,7 @@ static SQInteger default_delegate_tointeger(HSQUIRRELVM v)
 		v->Push(SQObjectPtr(_integer(o)?(SQInteger)1:(SQInteger)0));
 		break;
 	default:
-		v->Push(_null_);
+		v->PushNull();
 		break;
 	}
 	return 1;
@@ -331,7 +386,8 @@ static SQInteger default_delegate_tointeger(HSQUIRRELVM v)
 
 static SQInteger default_delegate_tostring(HSQUIRRELVM v)
 {
-	sq_tostring(v,1);
+	if(SQ_FAILED(sq_tostring(v,1))) 
+		return SQ_ERROR;
 	return 1;
 }
 
@@ -356,6 +412,7 @@ static SQInteger number_delegate_tochar(HSQUIRRELVM v)
 }
 
 
+
 /////////////////////////////////////////////////////////////////
 //TABLE DEFAULT DELEGATE
 
@@ -377,27 +434,41 @@ static SQInteger container_rawexists(HSQUIRRELVM v)
 	return 1;
 }
 
-static SQInteger table_rawset(HSQUIRRELVM v)
+static SQInteger container_rawset(HSQUIRRELVM v)
 {
 	return sq_rawset(v,-3);
 }
 
 
-static SQInteger table_rawget(HSQUIRRELVM v)
+static SQInteger container_rawget(HSQUIRRELVM v)
 {
 	return SQ_SUCCEEDED(sq_rawget(v,-2))?1:SQ_ERROR;
 }
 
+static SQInteger table_setdelegate(HSQUIRRELVM v)
+{
+	if(SQ_FAILED(sq_setdelegate(v,-2)))
+		return SQ_ERROR;
+	sq_push(v,-1); // -1 because sq_setdelegate pops 1
+	return 1;
+}
+
+static SQInteger table_getdelegate(HSQUIRRELVM v)
+{
+	return SQ_SUCCEEDED(sq_getdelegate(v,-1))?1:SQ_ERROR;
+}
 
 SQRegFunction SQSharedState::_table_default_delegate_funcz[]={
 	{_SC("len"),default_delegate_len,1, _SC("t")},
-	{_SC("rawget"),table_rawget,2, _SC("t")},
-	{_SC("rawset"),table_rawset,3, _SC("t")},
+	{_SC("rawget"),container_rawget,2, _SC("t")},
+	{_SC("rawset"),container_rawset,3, _SC("t")},
 	{_SC("rawdelete"),table_rawdelete,2, _SC("t")},
 	{_SC("rawin"),container_rawexists,2, _SC("t")},
 	{_SC("weakref"),obj_delegate_weakref,1, NULL },
 	{_SC("tostring"),default_delegate_tostring,1, _SC(".")},
 	{_SC("clear"),obj_clear,1, _SC(".")},
+	{_SC("setdelegate"),table_setdelegate,2, _SC(".t|o")},
+	{_SC("getdelegate"),table_getdelegate,1, _SC(".")},
 	{0,0}
 };
 
@@ -472,9 +543,113 @@ static SQInteger array_resize(HSQUIRRELVM v)
 	return sq_throwerror(v, _SC("size must be a number"));
 }
 
+static SQInteger __map_array(SQArray *dest,SQArray *src,HSQUIRRELVM v) {
+	SQObjectPtr temp;
+	SQInteger size = src->Size();
+	for(SQInteger n = 0; n < size; n++) {
+		src->Get(n,temp);
+		v->Push(src);
+		v->Push(temp);
+		if(SQ_FAILED(sq_call(v,2,SQTrue,SQFalse))) {
+			return SQ_ERROR;
+		}
+		dest->Set(n,v->GetUp(-1));
+		v->Pop();
+	}
+	return 0;
+}
 
-//QSORT ala Sedgewick
-bool _qsort_compare(HSQUIRRELVM v,SQObjectPtr &arr,SQObjectPtr &a,SQObjectPtr &b,SQInteger func,SQInteger &ret)
+static SQInteger array_map(HSQUIRRELVM v)
+{
+	SQObject &o = stack_get(v,1);
+	SQInteger size = _array(o)->Size();
+	SQObjectPtr ret = SQArray::Create(_ss(v),size);
+	if(SQ_FAILED(__map_array(_array(ret),_array(o),v)))
+		return SQ_ERROR;
+	v->Push(ret);
+	return 1;
+}
+
+static SQInteger array_apply(HSQUIRRELVM v)
+{
+	SQObject &o = stack_get(v,1);
+	if(SQ_FAILED(__map_array(_array(o),_array(o),v)))
+		return SQ_ERROR;
+	return 0;
+}
+
+static SQInteger array_reduce(HSQUIRRELVM v)
+{
+	SQObject &o = stack_get(v,1);
+	SQArray *a = _array(o);
+	SQInteger size = a->Size();
+	if(size == 0) {
+		return 0;
+	}
+	SQObjectPtr res;
+	a->Get(0,res);
+	if(size > 1) {
+		SQObjectPtr other;
+		for(SQInteger n = 1; n < size; n++) {
+			a->Get(n,other);
+			v->Push(o);
+			v->Push(res);
+			v->Push(other);
+			if(SQ_FAILED(sq_call(v,3,SQTrue,SQFalse))) {
+				return SQ_ERROR;
+			}
+			res = v->GetUp(-1);
+			v->Pop();
+		}
+	}
+	v->Push(res);
+	return 1;
+}
+
+static SQInteger array_filter(HSQUIRRELVM v)
+{
+	SQObject &o = stack_get(v,1);
+	SQArray *a = _array(o);
+	SQObjectPtr ret = SQArray::Create(_ss(v),0);
+	SQInteger size = a->Size();
+	SQObjectPtr val;
+	for(SQInteger n = 0; n < size; n++) {
+		a->Get(n,val);
+		v->Push(o);
+		v->Push(n);
+		v->Push(val);
+		if(SQ_FAILED(sq_call(v,3,SQTrue,SQFalse))) {
+			return SQ_ERROR;
+		}
+		if(!SQVM::IsFalse(v->GetUp(-1))) {
+			_array(ret)->Append(val);
+		}
+		v->Pop();
+	}
+	v->Push(ret);
+	return 1;
+}
+
+static SQInteger array_find(HSQUIRRELVM v)
+{
+	SQObject &o = stack_get(v,1);
+	SQObjectPtr &val = stack_get(v,2);
+	SQArray *a = _array(o);
+	SQInteger size = a->Size();
+	SQObjectPtr temp;
+	for(SQInteger n = 0; n < size; n++) {
+		bool res = false;
+		a->Get(n,temp);
+		if(SQVM::IsEqual(temp,val,res) && res) {
+			v->Push(n);
+			return 1;
+		}
+	}
+	return 0;
+}
+
+
+bool _sort_compare(HSQUIRRELVM v,SQObjectPtr &a,SQObjectPtr &b,SQInteger func,SQInteger &ret)
 {
 	if(func < 0) {
 		if(!v->ObjCmp(a,b,ret)) return false;
@@ -490,45 +665,69 @@ bool _qsort_compare(HSQUIRRELVM v,SQObjectPtr &arr,SQObjectPtr &a,SQObjectPtr &b
 				v->Raise_Error(_SC("compare func failed"));
 			return false;
 		}
-		sq_getinteger(v, -1, &ret);
+		if(SQ_FAILED(sq_getinteger(v, -1, &ret))) {
+			v->Raise_Error(_SC("numeric value expected as return value of the compare function"));
+			return false;
+		}
 		sq_settop(v, top);
 		return true;
 	}
 	return true;
 }
-//QSORT ala Sedgewick
-bool _qsort(HSQUIRRELVM v,SQObjectPtr &arr, SQInteger l, SQInteger r,SQInteger func)
+
+bool _hsort_sift_down(HSQUIRRELVM v,SQArray *arr, SQInteger root, SQInteger bottom, SQInteger func)
 {
-	SQInteger i, j;
-	SQArray *a=_array(arr);
-	SQObjectPtr pivot,t;
-	if( l < r ){
-		pivot = a->_values[l];
-		i = l; j = r+1;
-		while(1){
-			SQInteger ret;
-			do { 
-				++i; 
-				if(i > r) break;
-				if(!_qsort_compare(v,arr,a->_values[i],pivot,func,ret))
-					return false;
-			} while( ret <= 0);
-			do {
-				--j;
-				if ( j < 0 ) {
-					v->Raise_Error( _SC("Invalid qsort, probably compare function defect") ); 
-					return false; 
-				}
-				if(!_qsort_compare(v,arr,a->_values[j],pivot,func,ret))
-					return false;
-			}
-			while( ret > 0 );
-			if( i >= j ) break;
-			t = a->_values[i]; a->_values[i] = a->_values[j]; a->_values[j] = t;
+	SQInteger maxChild;
+	SQInteger done = 0;
+	SQInteger ret;
+	SQInteger root2;
+	while (((root2 = root * 2) <= bottom) && (!done))
+	{
+		if (root2 == bottom) {
+			maxChild = root2;
 		}
-		t = a->_values[l]; a->_values[l] = a->_values[j]; a->_values[j] = t;
-		if(!_qsort( v, arr, l, j-1,func)) return false;
-		if(!_qsort( v, arr, j+1, r,func)) return false;
+		else {
+			if(!_sort_compare(v,arr->_values[root2],arr->_values[root2 + 1],func,ret))
+				return false;
+			if (ret > 0) {
+				maxChild = root2;
+			}
+			else {
+				maxChild = root2 + 1;
+			}
+		}
+
+		if(!_sort_compare(v,arr->_values[root],arr->_values[maxChild],func,ret))
+			return false;
+		if (ret < 0) {
+			if (root == maxChild) {
+                v->Raise_Error(_SC("inconsistent compare function"));
+                return false; // We'd be swapping ourselve. The compare function is incorrect
+            }
+
+			_Swap(arr->_values[root],arr->_values[maxChild]);
+			root = maxChild;
+		}
+		else {
+			done = 1;
+		}
+	}
+	return true;
+}
+
+bool _hsort(HSQUIRRELVM v,SQObjectPtr &arr, SQInteger l, SQInteger r,SQInteger func)
+{
+	SQArray *a = _array(arr);
+	SQInteger i;
+	SQInteger array_size = a->Size();
+	for (i = (array_size / 2); i >= 0; i--) {
+		if(!_hsort_sift_down(v,a, i, array_size - 1,func)) return false;
+	}
+
+	for (i = array_size-1; i >= 1; i--)
+	{
+		_Swap(a->_values[0],a->_values[i]);
+		if(!_hsort_sift_down(v,a, 0, i-1,func)) return false;
 	}
 	return true;
 }
@@ -537,15 +736,15 @@ static SQInteger array_sort(HSQUIRRELVM v)
 {
 	SQInteger func = -1;
 	SQObjectPtr &o = stack_get(v,1);
-	SQObject &funcobj = stack_get(v,2);
 	if(_array(o)->Size() > 1) {
-		if(type(funcobj) == OT_CLOSURE || type(funcobj) == OT_NATIVECLOSURE) func = 2;
-		if(!_qsort(v, o, 0, _array(o)->Size()-1, func))
+		if(sq_gettop(v) == 2) func = 2;
+		if(!_hsort(v, o, 0, _array(o)->Size()-1, func))
 			return SQ_ERROR;
 
 	}
 	return 0;
 }
+
 static SQInteger array_slice(HSQUIRRELVM v)
 {
 	SQInteger sidx,eidx;
@@ -584,6 +783,11 @@ SQRegFunction SQSharedState::_array_default_delegate_funcz[]={
 	{_SC("weakref"),obj_delegate_weakref,1, NULL },
 	{_SC("tostring"),default_delegate_tostring,1, _SC(".")},
 	{_SC("clear"),obj_clear,1, _SC(".")},
+	{_SC("map"),array_map,2, _SC("ac")}, 
+	{_SC("apply"),array_apply,2, _SC("ac")}, 
+	{_SC("reduce"),array_reduce,2, _SC("ac")}, 
+	{_SC("filter"),array_filter,2, _SC("ac")},
+	{_SC("find"),array_find,2, _SC("a.")},
 	{0,0}
 };
 
@@ -699,12 +903,16 @@ static SQInteger closure_getinfos(HSQUIRRELVM v) {
 	SQObject o = stack_get(v,1);
 	SQTable *res = SQTable::Create(_ss(v),4);
 	if(type(o) == OT_CLOSURE) {
-		SQFunctionProto *f = _funcproto(_closure(o)->_function);
+		SQFunctionProto *f = _closure(o)->_function;
 		SQInteger nparams = f->_nparameters + (f->_varparams?1:0);
 		SQObjectPtr params = SQArray::Create(_ss(v),nparams);
+    SQObjectPtr defparams = SQArray::Create(_ss(v),f->_ndefaultparams);
 		for(SQInteger n = 0; n<f->_nparameters; n++) {
 			_array(params)->Set((SQInteger)n,f->_parameters[n]);
 		}
+    for(SQInteger j = 0; j<f->_ndefaultparams; j++) {
+			_array(defparams)->Set((SQInteger)j,_closure(o)->_defaultparams[j]);
+		}
 		if(f->_varparams) {
 			_array(params)->Set(nparams-1,SQString::Create(_ss(v),_SC("..."),-1));
 		}
@@ -713,6 +921,7 @@ static SQInteger closure_getinfos(HSQUIRRELVM v) {
 		res->NewSlot(SQString::Create(_ss(v),_SC("src"),-1),f->_sourcename);
 		res->NewSlot(SQString::Create(_ss(v),_SC("parameters"),-1),params);
 		res->NewSlot(SQString::Create(_ss(v),_SC("varargs"),-1),f->_varparams);
+    res->NewSlot(SQString::Create(_ss(v),_SC("defparams"),-1),defparams);
 	}
 	else { //OT_NATIVECLOSURE 
 		SQNativeClosure *nc = _nativeclosure(o);
@@ -734,6 +943,7 @@ static SQInteger closure_getinfos(HSQUIRRELVM v) {
 }
 
 
+
 SQRegFunction SQSharedState::_closure_default_delegate_funcz[]={
 	{_SC("call"),closure_call,-1, _SC("c")},
 	{_SC("pcall"),closure_pcall,-1, _SC("c")},
@@ -766,17 +976,15 @@ SQRegFunction SQSharedState::_generator_default_delegate_funcz[]={
 };
 
 //THREAD DEFAULT DELEGATE
-
 static SQInteger thread_call(HSQUIRRELVM v)
 {
-	
 	SQObjectPtr o = stack_get(v,1);
 	if(type(o) == OT_THREAD) {
 		SQInteger nparams = sq_gettop(v);
 		_thread(o)->Push(_thread(o)->_roottable);
 		for(SQInteger i = 2; i<(nparams+1); i++)
 			sq_move(_thread(o),v,i);
-		if(SQ_SUCCEEDED(sq_call(_thread(o),nparams,SQTrue,SQFalse))) {
+		if(SQ_SUCCEEDED(sq_call(_thread(o),nparams,SQTrue,SQTrue))) {
 			sq_move(v,_thread(o),-1);
 			sq_pop(_thread(o),1);
 			return 1;
@@ -842,46 +1050,117 @@ static SQInteger thread_getstatus(HSQUIRRELVM v)
 	return 1;
 }
 
+static SQInteger thread_getstackinfos(HSQUIRRELVM v)
+{
+	SQObjectPtr o = stack_get(v,1);
+	if(type(o) == OT_THREAD) {
+		SQVM *thread = _thread(o);
+		SQInteger threadtop = sq_gettop(thread);
+		SQInteger level;
+		sq_getinteger(v,-1,&level);
+		SQRESULT res = __getcallstackinfos(thread,level);
+		if(SQ_FAILED(res))
+		{
+			sq_settop(thread,threadtop);
+			if(type(thread->_lasterror) == OT_STRING) {
+				sq_throwerror(v,_stringval(thread->_lasterror));
+			}
+			else {
+				sq_throwerror(v,_SC("unknown error"));
+			}
+		}
+		if(res > 0) {
+			//some result
+			sq_move(v,thread,-1);
+			sq_settop(thread,threadtop);
+			return 1;
+		}
+		//no result
+		sq_settop(thread,threadtop);
+		return 0;
+		
+	}
+	return sq_throwerror(v,_SC("wrong parameter"));
+}
+
 SQRegFunction SQSharedState::_thread_default_delegate_funcz[] = {
 	{_SC("call"), thread_call, -1, _SC("v")},
 	{_SC("wakeup"), thread_wakeup, -1, _SC("v")},
 	{_SC("getstatus"), thread_getstatus, 1, _SC("v")},
 	{_SC("weakref"),obj_delegate_weakref,1, NULL },
+	{_SC("getstackinfos"),thread_getstackinfos,2, _SC("vn")},
 	{_SC("tostring"),default_delegate_tostring,1, _SC(".")},
 	{0,0},
 };
 
 static SQInteger class_getattributes(HSQUIRRELVM v)
 {
-	if(SQ_SUCCEEDED(sq_getattributes(v,-2)))
-		return 1;
-	return SQ_ERROR;
+	return SQ_SUCCEEDED(sq_getattributes(v,-2))?1:SQ_ERROR;
 }
 
 static SQInteger class_setattributes(HSQUIRRELVM v)
 {
-	if(SQ_SUCCEEDED(sq_setattributes(v,-3)))
-		return 1;
-	return SQ_ERROR;
+	return SQ_SUCCEEDED(sq_setattributes(v,-3))?1:SQ_ERROR;
 }
 
 static SQInteger class_instance(HSQUIRRELVM v)
 {
-	if(SQ_SUCCEEDED(sq_createinstance(v,-1)))
-		return 1;
-	return SQ_ERROR;
+	return SQ_SUCCEEDED(sq_createinstance(v,-1))?1:SQ_ERROR;
+}
+
+static SQInteger class_getbase(HSQUIRRELVM v)
+{
+	return SQ_SUCCEEDED(sq_getbase(v,-1))?1:SQ_ERROR;
+}
+
+static SQInteger class_newmember(HSQUIRRELVM v)
+{
+	SQInteger top = sq_gettop(v);
+	SQBool bstatic = SQFalse;
+	if(top == 5)
+	{
+		sq_tobool(v,-1,&bstatic);
+		sq_pop(v,1);
+	}
+
+	if(top < 4) {
+		sq_pushnull(v);
+	}
+	return SQ_SUCCEEDED(sq_newmember(v,-4,bstatic))?1:SQ_ERROR;
+}
+
+static SQInteger class_rawnewmember(HSQUIRRELVM v)
+{
+	SQInteger top = sq_gettop(v);
+	SQBool bstatic = SQFalse;
+	if(top == 5)
+	{
+		sq_tobool(v,-1,&bstatic);
+		sq_pop(v,1);
+	}
+
+	if(top < 4) {
+		sq_pushnull(v);
+	}
+	return SQ_SUCCEEDED(sq_rawnewmember(v,-4,bstatic))?1:SQ_ERROR;
 }
 
 SQRegFunction SQSharedState::_class_default_delegate_funcz[] = {
 	{_SC("getattributes"), class_getattributes, 2, _SC("y.")},
 	{_SC("setattributes"), class_setattributes, 3, _SC("y..")},
+	{_SC("rawget"),container_rawget,2, _SC("y")},
+	{_SC("rawset"),container_rawset,3, _SC("y")},
 	{_SC("rawin"),container_rawexists,2, _SC("y")},
 	{_SC("weakref"),obj_delegate_weakref,1, NULL },
 	{_SC("tostring"),default_delegate_tostring,1, _SC(".")},
 	{_SC("instance"),class_instance,1, _SC("y")},
+	{_SC("getbase"),class_getbase,1, _SC("y")},
+	{_SC("newmember"),class_newmember,-3, _SC("y")},
+	{_SC("rawnewmember"),class_rawnewmember,-3, _SC("y")},
 	{0,0}
 };
 
+
 static SQInteger instance_getclass(HSQUIRRELVM v)
 {
 	if(SQ_SUCCEEDED(sq_getclass(v,1)))
@@ -891,6 +1170,8 @@ static SQInteger instance_getclass(HSQUIRRELVM v)
 
 SQRegFunction SQSharedState::_instance_default_delegate_funcz[] = {
 	{_SC("getclass"), instance_getclass, 1, _SC("x")},
+	{_SC("rawget"),container_rawget,2, _SC("x")},
+	{_SC("rawset"),container_rawset,3, _SC("x")},
 	{_SC("rawin"),container_rawexists,2, _SC("x")},
 	{_SC("weakref"),obj_delegate_weakref,1, NULL },
 	{_SC("tostring"),default_delegate_tostring,1, _SC(".")},
@@ -911,4 +1192,3 @@ SQRegFunction SQSharedState::_weakref_default_delegate_funcz[] = {
 	{0,0}
 };
 
-
