@@ -2,6 +2,6 @@
 #define _STDINT_H
 
 // SDL config declares most stdint.h stuff...
-#include <sdl_config_win32.h>
+#include <cstdint>
 
 #endif
\ No newline at end of file
