@@ -34,12 +34,15 @@
 #include "lisp/list_iterator.hpp"
 #include "lisp/parser.hpp"
 #include "util/file_system.hpp"
+#include "util/gettext.hpp"
 #include "util/log.hpp"
 #include "util/reader.hpp"
 #include "util/writer.hpp"
 
 namespace {
 
+static const char* ADDON_INFO_PATH = "/addons/repository.nfo";
+
 MD5 md5_from_file(const std::string& filename)
 {
   // TODO: this does not work as expected for some files -- IFileStream seems to not always behave like an ifstream.
@@ -78,6 +81,24 @@ bool has_suffix(const std::string& str, const std::string& suffix)
     return false;
 }
 
+static void add_to_dictionary_path(void *data, const char *origdir, const char *fname)
+{
+    std::string full_path = std::string(origdir) + "/" + std::string(fname);
+    if(PHYSFS_isDirectory(full_path.c_str()))
+    {
+        log_debug << "Adding \"" << full_path << "\" to dictionary search path" << std::endl;
+        g_dictionary_manager->add_directory(full_path);
+    }
+}
+
+static void remove_from_dictionary_path(void *data, const char *origdir, const char *fname)
+{
+    std::string full_path = std::string(origdir) + "/" + std::string(fname);
+    if(PHYSFS_isDirectory(full_path.c_str()))
+    {
+        g_dictionary_manager->remove_directory(full_path);
+    }
+}
 } // namespace
 
 AddonManager::AddonManager(const std::string& addon_directory,
@@ -111,13 +132,20 @@ AddonManager::AddonManager(const std::string& addon_directory,
     }
   }
 
-  try
+  if(PHYSFS_exists(ADDON_INFO_PATH))
   {
-    m_repository_addons = parse_addon_infos("/addons/repository.nfo");
+    try
+    {
+        m_repository_addons = parse_addon_infos(ADDON_INFO_PATH);
+    }
+    catch(const std::exception& err)
+    {
+        log_warning << "parsing repository.nfo failed: " << err.what() << std::endl;
+    }
   }
-  catch(const std::exception& err)
+  else
   {
-    log_warning << "parsing repository.nfo failed: " << err.what() << std::endl;
+    log_info << "repository.nfo doesn't exist, not loading" << std::endl;
   }
 }
 
@@ -219,7 +247,7 @@ AddonManager::request_check_online()
   }
   else
   {
-    m_transfer_status = m_downloader.request_download(m_repository_url, "/addons/repository.nfo");
+    m_transfer_status = m_downloader.request_download(m_repository_url, ADDON_INFO_PATH);
 
     m_transfer_status->then(
       [this](bool success)
@@ -228,7 +256,7 @@ AddonManager::request_check_online()
 
         if (success)
         {
-          m_repository_addons = parse_addon_infos("/addons/repository.nfo");
+          m_repository_addons = parse_addon_infos(ADDON_INFO_PATH);
           m_has_been_updated = true;
         }
       });
@@ -240,8 +268,8 @@ AddonManager::request_check_online()
 void
 AddonManager::check_online()
 {
-  m_downloader.download(m_repository_url, "/addons/repository.nfo");
-  m_repository_addons = parse_addon_infos("/addons/repository.nfo");
+  m_downloader.download(m_repository_url, ADDON_INFO_PATH);
+  m_repository_addons = parse_addon_infos(ADDON_INFO_PATH);
   m_has_been_updated = true;
 }
 
@@ -413,6 +441,10 @@ AddonManager::enable_addon(const AddonId& addon_id)
     }
     else
     {
+      if(addon.get_type() == Addon::LANGUAGEPACK)
+      {
+        PHYSFS_enumerateFilesCallback(addon.get_id().c_str(), add_to_dictionary_path, NULL);
+      }
       addon.set_enabled(true);
     }
   }
@@ -437,6 +469,10 @@ AddonManager::disable_addon(const AddonId& addon_id)
     }
     else
     {
+      if(addon.get_type() == Addon::LANGUAGEPACK)
+      {
+        PHYSFS_enumerateFilesCallback(addon.get_id().c_str(), remove_from_dictionary_path, NULL);
+      }
       addon.set_enabled(false);
     }
   }
@@ -598,4 +634,52 @@ AddonManager::update()
   m_downloader.update();
 }
 
+void
+AddonManager::check_for_langpack_updates()
+{
+  const std::string& language = g_dictionary_manager->get_language().get_language();
+  if(language == "en")
+    return;
+
+  try
+  {
+    check_online();
+    try
+    {
+      const std::string& addon_id = "langpack-" + language;
+      log_debug << "Looking for language addon with ID " << addon_id << "..." << std::endl;
+      Addon& langpack = get_repository_addon(addon_id);
+
+      try
+      {
+        Addon& installed_langpack = get_installed_addon(addon_id);
+        if (installed_langpack.get_md5() == langpack.get_md5() ||
+            installed_langpack.get_version() > langpack.get_version())
+        {
+          log_debug << "Language addon " << addon_id << " is already the latest version." << std::endl;
+          return;
+        }
+
+        // Langpack update available. Let's install it!
+        install_addon(addon_id);
+        enable_addon(addon_id);
+      }
+      catch(const std::exception& err)
+      {
+        log_debug << "Language addon " << addon_id << " is not installed. Installing..." << std::endl;
+        install_addon(addon_id);
+        enable_addon(addon_id);
+      }
+    }
+    catch(std::exception& err)
+    {
+      log_debug << "Language addon for current locale not found." << std::endl;
+    }
+  }
+  catch(...)
+  {
+    // If anything fails here, just silently ignore.
+  }
+}
+
 /* EOF */
