@@ -134,7 +134,7 @@ SoundManager::intern_create_sound_source(const std::string& filename)
   }
 
   alSourcei(source->source, AL_BUFFER, buffer);
-  return std::move(source);
+  return source;
 }
 
 std::unique_ptr<SoundSource>
@@ -315,6 +315,37 @@ SoundManager::pause_music(float fadetime)
   }
 }
 
+void
+SoundManager::pause_sounds()
+{
+  for(SoundSources::iterator i = sources.begin(); i != sources.end(); ++i) {
+    auto& source = *i;
+    if(source->playing()) {
+      source->pause();
+    }
+  }
+}
+
+void
+SoundManager::resume_sounds()
+{
+  for(SoundSources::iterator i = sources.begin(); i != sources.end(); ++i) {
+    auto& source = *i;
+    if(source->paused()) {
+      source->resume();
+    }
+  }
+}
+
+void
+SoundManager::stop_sounds()
+{
+    for(SoundSources::iterator i = sources.begin(); i != sources.end(); ++i) {
+        auto& source = *i;
+        source->stop();
+    }
+}
+
 void
 SoundManager::resume_music(float fadetime)
 {
