@@ -68,6 +68,10 @@ public:
   void resume_music(float fadetime = 0);
   void stop_music(float fadetime = 0);
 
+  void pause_sounds();
+  void resume_sounds();
+  void stop_sounds();
+
   bool is_music_enabled() const { return music_enabled; }
   bool is_sound_enabled() const { return sound_enabled; }
 
@@ -97,7 +101,7 @@ private:
   static ALuint load_file_into_buffer(SoundFile& file);
   static ALenum get_sample_format(const SoundFile& file);
 
-  void print_openal_version();
+  static void print_openal_version();
   void check_alc_error(const char* message);
   static void check_al_error(const char* message);
 
