@@ -80,36 +80,42 @@ void
 AngryStone::active_update(float elapsed_time) {
   BadGuy::active_update(elapsed_time);
 
-  if (state == IDLE) {
-    MovingObject* player = this->get_nearest_player();
-    if(player) {
-      MovingObject* badguy = this;
-      const Vector playerPos = player->get_pos();
-      const Vector badguyPos = badguy->get_pos();
-      float dx = (playerPos.x - badguyPos.x);
-      float dy = (playerPos.y - badguyPos.y);
+  if (frozen) {
+    return;
+  }
 
-      float playerHeight = player->get_bbox().p2.y - player->get_bbox().p1.y;
-      float badguyHeight = badguy->get_bbox().p2.y - badguy->get_bbox().p1.y;
+  switch (state) {
 
-      float playerWidth = player->get_bbox().p2.x - player->get_bbox().p1.x;
-      float badguyWidth = badguy->get_bbox().p2.x - badguy->get_bbox().p1.x;
 
-      if ((dx > -playerWidth) && (dx < badguyWidth)) {
-        if (dy > 0) {
-          attackDirection.x = 0;
-          attackDirection.y = 1;
-        } else {
-          attackDirection.x = 0;
-          attackDirection.y = -1;
-        }
-        if ((attackDirection.x != oldWallDirection.x) || (attackDirection.y != oldWallDirection.y)) {
-          sprite->set_action("charging");
-          timer.start(CHARGE_TIME);
-          state = CHARGING;
-        }
-      } else
-        if ((dy > -playerHeight) && (dy < badguyHeight)) {
+    case IDLE: {
+      MovingObject* player = get_nearest_player();
+      if(player) {
+        MovingObject* badguy = this;
+        const Vector playerPos = player->get_pos();
+        const Vector badguyPos = badguy->get_pos();
+        float dx = (playerPos.x - badguyPos.x);
+        float dy = (playerPos.y - badguyPos.y);
+
+        float playerHeight = player->get_bbox().p2.y - player->get_bbox().p1.y;
+        float badguyHeight = badguy->get_bbox().p2.y - badguy->get_bbox().p1.y;
+
+        float playerWidth = player->get_bbox().p2.x - player->get_bbox().p1.x;
+        float badguyWidth = badguy->get_bbox().p2.x - badguy->get_bbox().p1.x;
+
+        if ((dx > -playerWidth) && (dx < badguyWidth)) {
+          if (dy > 0) {
+            attackDirection.x = 0;
+            attackDirection.y = 1;
+          } else {
+            attackDirection.x = 0;
+            attackDirection.y = -1;
+          }
+          if ((attackDirection.x != oldWallDirection.x) || (attackDirection.y != oldWallDirection.y)) {
+            sprite->set_action("charging");
+            timer.start(CHARGE_TIME);
+            state = CHARGING;
+          }
+        } else if ((dy > -playerHeight) && (dy < badguyHeight)) {
           if (dx > 0) {
             attackDirection.x = 1;
             attackDirection.y = 0;
@@ -123,44 +129,56 @@ AngryStone::active_update(float elapsed_time) {
             state = CHARGING;
           }
         }
+      }
+    } break;
 
-    }
-  }
+    case CHARGING: {
+      if (timer.check()) {
+        sprite->set_action("attacking");
+        timer.start(ATTACK_TIME);
+        state = ATTACKING;
+        physic.enable_gravity(false);
+        physic.set_velocity_x(CHARGE_SPEED * attackDirection.x);
+        physic.set_velocity_y(CHARGE_SPEED * attackDirection.y);
+        oldWallDirection.x = 0;
+        oldWallDirection.y = 0;
+      }
+    } break;
 
-  if (state == CHARGING) {
-    if (timer.check()) {
-      sprite->set_action("attacking");
-      timer.start(ATTACK_TIME);
-      state = ATTACKING;
-      physic.enable_gravity(false);
-      physic.set_velocity_x(CHARGE_SPEED * attackDirection.x);
-      physic.set_velocity_y(CHARGE_SPEED * attackDirection.y);
-      oldWallDirection.x = 0;
-      oldWallDirection.y = 0;
-    }
-  }
+    case ATTACKING: {
+      if (timer.check()) {
+        timer.start(RECOVER_TIME);
+        state = RECOVERING;
+        sprite->set_action("idle");
+        physic.enable_gravity(true);
+        physic.set_velocity_x(0);
+        physic.set_velocity_y(0);
+      }
+    } break;
 
-  if (state == ATTACKING) {
-    if (timer.check()) {
-      timer.start(RECOVER_TIME);
-      state = RECOVERING;
-      sprite->set_action("idle");
-      physic.enable_gravity(true);
-      physic.set_velocity_x(0);
-      physic.set_velocity_y(0);
-    }
-  }
-
-  if (state == RECOVERING) {
-    if (timer.check()) {
-      state = IDLE;
-      sprite->set_action("idle");
-      physic.enable_gravity(true);
-      physic.set_velocity_x(0);
-      physic.set_velocity_y(0);
-    }
+    case RECOVERING: {
+      if (timer.check()) {
+        state = IDLE;
+        sprite->set_action("idle");
+        physic.enable_gravity(true);
+        physic.set_velocity_x(0);
+        physic.set_velocity_y(0);
+      }
+    } break;
   }
 
 }
 
+bool
+AngryStone::is_freezable() const
+{
+  return state != ATTACKING;
+}
+
+bool
+AngryStone::is_flammable() const
+{
+  return false;
+}
+
 /* EOF */
