@@ -19,6 +19,8 @@
 #include "sprite/sprite.hpp"
 #include "supertux/object_factory.hpp"
 
+#include <algorithm>
+
 static const float JUMPSPEED = -450;
 static const float BSNOWBALL_WALKSPEED = 80;
 
@@ -57,7 +59,8 @@ BouncingSnowball::collision_solid(const CollisionHit& hit)
 
   if(hit.bottom) {
     if(get_state() == STATE_ACTIVE) {
-      physic.set_velocity_y(JUMPSPEED);
+      float bounce_speed = -physic.get_velocity_y()*0.8;
+      physic.set_velocity_y(std::min(JUMPSPEED, bounce_speed));
     } else {
       physic.set_velocity_y(0);
     }
@@ -65,11 +68,14 @@ BouncingSnowball::collision_solid(const CollisionHit& hit)
     physic.set_velocity_y(0);
   }
 
-  if(hit.left || hit.right) { // left or right collision
+  // left or right collision
+  // The direction must correspond, else we got fake bounces on slopes.
+  if((hit.left && dir == LEFT) || (hit.right && dir == RIGHT)) {
     dir = dir == LEFT ? RIGHT : LEFT;
     sprite->set_action(dir == LEFT ? "left" : "right");
     physic.set_velocity_x(-physic.get_velocity_x());
   }
+
 }
 
 HitResponse
