@@ -28,7 +28,7 @@ public:
   virtual void active_update(float elapsed_time);
   void collision_solid(const CollisionHit& hit);
 
-  bool might_climb(int width, int height);
+  bool might_climb(int width, int height) const;
 
 protected:
   bool collision_squished(GameObject& object);
