@@ -31,6 +31,7 @@ public:
   void freeze();
   void unfreeze();
   bool is_freezable() const;
+  bool is_flammable() const;
 
 protected:
   bool collision_squished(GameObject& object);
@@ -38,6 +39,10 @@ protected:
   void launch_badguy();
 
 private:
+
+  /** CollisionGroup the badguy should be in while active */
+  CollisionGroup colgroup_active;
+
   float cycle;
   std::vector<std::string> badguys;
   unsigned int next_badguy;
@@ -46,7 +51,12 @@ private:
   bool swivel;
   bool broken;
   bool random;
-  std::string type;
+
+  typedef enum {
+    DT_DROPPER, DT_ROCKETLAUNCHER, DT_CANNON
+  }DispenserType;
+
+  DispenserType type;
 };
 
 #endif
