@@ -28,12 +28,14 @@ public:
   Haywire(const Vector& pos, Direction d);
 
   void kill_fall();
+  void ignite();
   HitResponse collision(GameObject& object, const CollisionHit& hit);
   HitResponse collision_player(Player& player, const CollisionHit& hit);
 
   void active_update(float elapsed_time);
 
   bool is_freezable() const;
+  void freeze();
 
 protected:
   bool collision_squished(GameObject& object);
