@@ -57,9 +57,10 @@ Jumpy::hit(const CollisionHit& chit)
       groundhit_pos_set = true;
     }
 
-    physic.set_velocity_y((frozen || get_state() == STATE_FALLING) ? 0 : JUMPYSPEED);
+    physic.set_velocity_y((frozen || get_state() != STATE_ACTIVE) ? 0 : JUMPYSPEED);
     // TODO create a nice sound for this...
     //SoundManager::current()->play("sounds/skid.wav");
+    update_on_ground_flag(chit);
   } else if(chit.top) {
     physic.set_velocity_y(0);
   }
@@ -75,7 +76,7 @@ Jumpy::active_update(float elapsed_time)
   if(frozen)
     return;
 
-  Player* player = this->get_nearest_player();
+  Player* player = get_nearest_player();
   if (player)
   {
     dir = (player->get_pos().x > get_pos().x) ? RIGHT : LEFT;
@@ -109,4 +110,10 @@ Jumpy::is_freezable() const
   return true;
 }
 
+bool
+Jumpy::is_flammable() const
+{
+  return true;
+}
+
 /* EOF */
