@@ -18,8 +18,10 @@
 
 #include <math.h>
 
+#include "audio/sound_manager.hpp"
 #include "math/random_generator.hpp"
 #include "object/camera.hpp"
+#include "object/electrifier.hpp"
 #include "object/player.hpp"
 #include "sprite/sprite.hpp"
 #include "sprite/sprite_manager.hpp"
@@ -50,6 +52,8 @@ Kugelblitz::Kugelblitz(const Reader& reader) :
 
   lightsprite->set_blend(Blend(GL_SRC_ALPHA, GL_ONE));
   lightsprite->set_color(Color(0.2f, 0.1f, 0.0f));
+
+  SoundManager::current()->preload("sounds/lightning.wav");
 }
 
 void
@@ -76,7 +80,7 @@ Kugelblitz::collision_player(Player& player, const CollisionHit& )
   }
   // hit from above?
   if(player.get_movement().y - get_movement().y > 0 && player.get_bbox().p2.y <
-     (get_bbox().p1.y + get_bbox().p2.y) / 2) {
+     (bbox.p1.y + bbox.p2.y) / 2) {
     // if it's not is it possible to squish us, then this will hurt
     if(!collision_squished(player))
       player.kill(false);
@@ -116,8 +120,6 @@ Kugelblitz::hit(const CollisionHit& hit_)
     movement_timer.start(MOVETIME);
     lifetime.start(LIFETIME);
 
-  } else if(hit_.top) { // bumped on roof
-    physic.set_velocity_y(0);
   }
 
   return CONTINUE;
@@ -138,18 +140,12 @@ Kugelblitz::active_update(float elapsed_time)
         movement_timer.start(MOVETIME);
       }
     }
-    /*
-      if (Sector::current()->solids->get_tile_at(get_pos())->getAttributes() == 16) {
-      //HIT WATER
-      Sector::current()->add_object(new Electrifier(75,1421,1.5));
-      Sector::current()->add_object(new Electrifier(76,1422,1.5));
+
+    if (is_in_water()) {
+      Sector::current()->add_object( std::make_shared<Electrifier>(75,1421,1.5));
+      Sector::current()->add_object( std::make_shared<Electrifier>(76,1422,1.5));
       explode();
-      }
-      if (Sector::current()->solids->get_tile_at(get_pos())->getAttributes() == 48) {
-      //HIT ELECTRIFIED WATER
-      explode();
-      }
-    */
+    }
   }
   BadGuy::active_update(elapsed_time);
 }
@@ -160,12 +156,12 @@ Kugelblitz::draw(DrawingContext& context)
   sprite->draw(context, get_pos(), layer);
 
   //Only draw light in dark areas
-  context.get_light( get_bbox().get_middle(), &light );
+  context.get_light( bbox.get_middle(), &light );
   if (light.red + light.green < 2.0){
     context.push_target();
     context.set_target(DrawingContext::LIGHTMAP);
     sprite->draw(context, get_pos(), layer);
-    lightsprite->draw(context, get_bbox().get_middle(), 0);
+    lightsprite->draw(context, bbox.get_middle(), 0);
     context.pop_target();
   }
 }
@@ -173,12 +169,14 @@ Kugelblitz::draw(DrawingContext& context)
 void
 Kugelblitz::kill_fall()
 {
+  explode();
 }
 
 void
 Kugelblitz::explode()
 {
   if (!dying) {
+    SoundManager::current()->play("sounds/lightning.wav", bbox.p1);
     sprite->set_action("pop");
     lifetime.start(0.2f);
     dying = true;
@@ -195,7 +193,7 @@ Kugelblitz::try_activate()
 
   Player* player_ = get_nearest_player();
   if (!player_) return;
-  Vector dist = player_->get_bbox().get_middle() - get_bbox().get_middle();
+  Vector dist = player_->get_bbox().get_middle() - bbox.get_middle();
   if ((fabsf(dist.x) <= X_OFFSCREEN_DISTANCE) && (fabsf(dist.y) <= Y_OFFSCREEN_DISTANCE)) {
     set_state(STATE_ACTIVE);
     if (!is_initialized) {
@@ -203,7 +201,7 @@ Kugelblitz::try_activate()
       // if starting direction was set to AUTO, this is our chance to re-orient the badguy
       if (start_dir == AUTO) {
         Player* player__ = get_nearest_player();
-        if (player__ && (player__->get_bbox().p1.x > get_bbox().p2.x)) {
+        if (player__ && (player__->get_bbox().p1.x > bbox.p2.x)) {
           dir = RIGHT;
         } else {
           dir = LEFT;
@@ -217,4 +215,10 @@ Kugelblitz::try_activate()
   }
 }
 
+bool
+Kugelblitz::is_flammable() const
+{
+  return false;
+}
+
 /* EOF */
