@@ -105,13 +105,19 @@ MrBomb::kill_fall()
 {
   if(is_valid()) {
     remove_me();
-    auto explosion = std::make_shared<Explosion>(get_bbox().get_middle());
+    auto explosion = std::make_shared<Explosion>(bbox.get_middle());
     Sector::current()->add_object(explosion);
   }
 
   run_dead_script();
 }
 
+void
+MrBomb::ignite()
+{
+  kill_fall();
+}
+
 void
 MrBomb::grab(MovingObject&, const Vector& pos, Direction dir_)
 {
