@@ -76,7 +76,7 @@ Owl::initialize()
 bool
 Owl::is_above_player (void)
 {
-  Player* player = Sector::current()->get_nearest_player (this->get_bbox ());
+  Player* player = Sector::current()->get_nearest_player (bbox);
   if (!player)
     return false;
 
@@ -85,11 +85,10 @@ Owl::is_above_player (void)
   float x_offset = (dir == LEFT) ? ACTIVATION_DISTANCE : -ACTIVATION_DISTANCE;
 
   const Rectf& player_bbox = player->get_bbox();
-  const Rectf& owl_bbox = get_bbox();
 
-  if ((player_bbox.p1.y >= owl_bbox.p2.y) /* player is below us */
-      && ((player_bbox.p2.x + x_offset) > owl_bbox.p1.x)
-      && ((player_bbox.p1.x + x_offset) < owl_bbox.p2.x))
+  if ((player_bbox.p1.y >= bbox.p2.y) /* player is below us */
+      && ((player_bbox.p2.x + x_offset) > bbox.p1.x)
+      && ((player_bbox.p1.x + x_offset) < bbox.p2.x))
     return true;
   else
     return false;
@@ -128,7 +127,7 @@ Owl::active_update (float elapsed_time)
 bool
 Owl::collision_squished(GameObject&)
 {
-  Player* player = Sector::current()->get_nearest_player (this->get_bbox ());
+  Player* player = Sector::current()->get_nearest_player (bbox);
   if (player)
     player->bounce (*this);
 
@@ -209,5 +208,14 @@ Owl::collision_solid(const CollisionHit& hit)
   }
 } /* void Owl::collision_solid */
 
+void
+Owl::ignite() {
+  if (carried_object != NULL) {
+    carried_object->ungrab (*this, dir);
+    carried_object = NULL;
+  }
+  BadGuy::ignite();
+}
+
 /* vim: set sw=2 sts=2 et fdm=marker : */
 /* EOF */
