@@ -101,5 +101,11 @@ ShortFuse::kill_fall (void)
   explode ();
 }
 
+void
+ShortFuse::ignite()
+{
+  kill_fall();
+}
+
 /* vim: set sw=2 sts=2 et : */
 /* EOF */
