@@ -32,7 +32,7 @@ public:
   void collision_solid(const CollisionHit& hit);
   HitResponse collision_badguy(BadGuy& badguy, const CollisionHit& hit);
   HitResponse collision_player(Player& player, const CollisionHit& hit);
-  bool can_break();
+  bool can_break() const;
 
   void active_update(float elapsed_time);
 
