@@ -1,5 +1,5 @@
 //  SuperTux
-//  Copyright (C) 2010 Ingo Ruhnke <grumbel@gmx.de>
+//  Copyright (C) 2010 Ingo Ruhnke <grumbel@gmail.com>
 //
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,10 @@ public:
   Snowman(const Vector& pos, Direction d);
 
 protected:
+  void loose_head();
+  virtual HitResponse collision_bullet(Bullet& bullet, const CollisionHit& hit);
   bool collision_squished(GameObject& object);
+
 };
 
 #endif
