@@ -84,7 +84,7 @@ SpiderMite::active_update(float elapsed_time)
   }
   movement=physic.get_movement(elapsed_time);
 
-  Player* player = this->get_nearest_player();
+  Player* player = get_nearest_player();
   if (player) {
     dir = (player->get_pos().x > get_pos().x) ? RIGHT : LEFT;
     sprite->set_action(dir == LEFT ? "left" : "right");
