@@ -91,9 +91,9 @@ Totem::active_update(float elapsed_time)
         if (!t) continue;
 
         // skip if we are not approaching each other
-        if (!((this->dir == LEFT) && (t->dir == RIGHT))) continue;
+        if (!((dir == LEFT) && (t->dir == RIGHT))) continue;
 
-        Vector p1 = this->get_pos();
+        Vector p1 = bbox.p1;
         Vector p2 = t->get_pos();
 
         // skip if not on same height
@@ -125,7 +125,12 @@ Totem::active_update(float elapsed_time)
 bool
 Totem::collision_squished(GameObject& object)
 {
-  if (carrying) carrying->jump_off();
+  /// Tux shouldn't be able to bisect totem stack by sacrificing his powerup.
+  /// --Hume2
+  if (carrying) {
+    return false;
+  }
+
   if (carried_by) {
     Player* player = dynamic_cast<Player*>(&object);
     if (player) player->bounce(*this);
