@@ -27,6 +27,7 @@
 #include "supertux/game_session.hpp"
 #include "supertux/object_factory.hpp"
 #include "supertux/sector.hpp"
+#include "util/log.hpp"
 #include "util/reader.hpp"
 
 static const float FLYSPEED = 64; /**< speed in px per second */
@@ -90,7 +91,7 @@ WillOWisp::draw(DrawingContext& context)
   context.set_target(DrawingContext::LIGHTMAP);
 
   sprite->draw(context, get_pos(), layer);
-  lightsprite->draw(context, get_bbox().get_middle(), 0);
+  lightsprite->draw(context, bbox.get_middle(), 0);
 
   context.pop_target();
 }
@@ -100,8 +101,8 @@ WillOWisp::active_update(float elapsed_time)
 {
   Player* player = get_nearest_player();
   if (!player) return;
-  Vector p1 = this->get_pos() + (this->get_bbox().p2 - this->get_bbox().p1) / 2;
-  Vector p2 = player->get_pos() + (player->get_bbox().p2 - player->get_bbox().p1) / 2;
+  Vector p1 = bbox.get_middle();
+  Vector p2 = player->get_bbox().get_middle();
   Vector dist = (p2 - p1);
 
   switch(mystate) {
@@ -270,10 +271,7 @@ WillOWisp::set_state(const std::string& new_state)
   } else if(new_state == "vanish") {
     vanish();
   } else {
-    std::ostringstream msg;
-    msg << "Can't set unknown willowisp state '" << new_state << "', should "
-      "be stopped, move_path, move_path_track or normal";
-    throw new std::runtime_error(msg.str());
+    log_warning << "Can't set unknown willowisp state '" << new_state << std::endl;
   }
 }
 
