@@ -61,7 +61,7 @@ Yeti::Yeti(const Reader& reader) :
   hud_head()
 {
   hit_points = INITIAL_HITPOINTS;
-  countMe = false;
+  countMe = true;
   SoundManager::current()->preload("sounds/yeti_gna.wav");
   SoundManager::current()->preload("sounds/yeti_roar.wav");
   hud_head = Surface::create("images/creatures/yeti/hudlife.png");
@@ -239,11 +239,11 @@ Yeti::drop_stalactite()
   // make a stalactite falling down and shake camera a bit
   Sector::current()->camera->shake(.1f, 0, 10);
 
-  Player* player = this->get_nearest_player();
+  Player* player = get_nearest_player();
   if (!player) return;
 
   Sector* sector = Sector::current();
-  for(Sector::GameObjects::iterator i = sector->gameobjects.begin();
+  for(Sector::GameObjects::const_iterator i = sector->gameobjects.begin();
       i != sector->gameobjects.end(); ++i) {
     YetiStalactite* stalactite = dynamic_cast<YetiStalactite*>(i->get());
     if(stalactite && stalactite->is_hanging()) {
@@ -303,4 +303,10 @@ Yeti::collision_solid(const CollisionHit& hit)
   }
 }
 
+bool
+Yeti::is_flammable() const
+{
+  return false;
+}
+
 /* EOF */
