@@ -97,7 +97,7 @@ Zeekling::onBumpHorizontal() {
 
 void
 Zeekling::onBumpVertical() {
-  if (frozen)
+  if (frozen || BadGuy::get_state() == STATE_BURNING)
   {
     physic.set_velocity_y(0);
     physic.set_velocity_x(0);
@@ -141,13 +141,13 @@ Zeekling::should_we_dive() {
   if (frozen)
     return false;
 
-  const MovingObject* player = this->get_nearest_player();
+  const MovingObject* player = get_nearest_player();
   if (player && last_player && (player == last_player)) {
 
     // get positions, calculate movement
     const Vector player_pos = player->get_pos();
     const Vector player_mov = (player_pos - last_player_pos);
-    const Vector self_pos = this->get_pos();
+    const Vector self_pos = bbox.p1;
     const Vector self_mov = (self_pos - last_self_pos);
 
     // new vertical speed to test with
@@ -181,7 +181,7 @@ Zeekling::should_we_dive() {
   last_player = player;
   if (player) {
     last_player_pos = player->get_pos();
-    last_self_pos = this->get_pos();
+    last_self_pos = bbox.p1;
   }
 
   return false;
