@@ -23,6 +23,7 @@
 #include "gui/menu.hpp"
 #include "gui/mousecursor.hpp"
 #include "math/sizef.hpp"
+#include "supertux/gameconfig.hpp"
 #include "supertux/globals.hpp"
 #include "supertux/menu/menu_storage.hpp"
 #include "supertux/timer.hpp"
@@ -90,6 +91,12 @@ public:
 
   void update()
   {
+    if (!g_config->transitions_enabled && m_is_active)
+    {
+      m_effect_progress = 1.0f;
+      m_is_active = false;
+      return;
+    }
     if (m_is_active)
     {
       m_effect_progress = (real_time - m_effect_start_time) * 6.0f;
@@ -129,7 +136,7 @@ public:
                              LAYER_GUI-10);
   }
 
-  bool is_active()
+  bool is_active() const
   {
     return m_is_active;
   }
@@ -162,7 +169,7 @@ MenuManager::refresh()
 void
 MenuManager::process_input()
 {
-  if (m_dialog)
+  if (m_dialog && !m_dialog->is_passive())
   {
     m_dialog->process_input(*InputManager::current()->get_controller());
   }
@@ -177,7 +184,7 @@ MenuManager::event(const SDL_Event& ev)
 {
   if (!m_transition->is_active())
   {
-    if (m_dialog)
+    if (m_dialog && !m_dialog->is_passive())
     {
       m_dialog->event(ev);
     }
@@ -211,7 +218,7 @@ MenuManager::draw(DrawingContext& context)
       m_dialog->update();
       m_dialog->draw(context);
     }
-    else if (current_menu())
+    if (current_menu() && (!m_dialog || m_dialog->is_passive()))
     {
       // brute force the transition into the right shape in case the
       // menu has changed sizes
