@@ -75,17 +75,17 @@ BicyclePlatform::collision(GameObject& other, const CollisionHit& )
   // somehow the hit parameter does not get filled in, so to determine (hit.top == true) we do this:
   MovingObject* mo = dynamic_cast<MovingObject*>(&other);
   if (!mo) return FORCE_MOVE;
-  if ((mo->get_bbox().p2.y) > (get_bbox().p1.y + 2)) return FORCE_MOVE;
+  if ((mo->get_bbox().p2.y) > (bbox.p1.y + 2)) return FORCE_MOVE;
 
   Player* pl = dynamic_cast<Player*>(mo);
   if (pl) {
-    if (pl->is_big()) momentum += 1;
+    if (pl->is_big()) momentum += 0.1 * Sector::current()->get_gravity();
     Portable* po = pl->get_grabbed_object();
     MovingObject* pomo = dynamic_cast<MovingObject*>(po);
-    if (contacts.insert(pomo).second) momentum += 1;
+    if (contacts.insert(pomo).second) momentum += 0.1 * Sector::current()->get_gravity();
   }
 
-  if (contacts.insert(&other).second) momentum += 1;
+  if (contacts.insert(&other).second) momentum += 0.1 * Sector::current()->get_gravity();
   return FORCE_MOVE;
 }
 
