@@ -18,12 +18,14 @@
 
 #include "audio/sound_manager.hpp"
 #include "badguy/badguy.hpp"
+#include "lisp/list_iterator.hpp"
 #include "object/broken_brick.hpp"
 #include "object/coin.hpp"
 #include "object/flower.hpp"
 #include "object/growup.hpp"
 #include "object/player.hpp"
 #include "object/portable.hpp"
+#include "sprite/sprite_manager.hpp"
 #include "supertux/constants.hpp"
 #include "supertux/sector.hpp"
 
@@ -45,6 +47,27 @@ Block::Block(SpritePtr newsprite) :
   SoundManager::current()->preload("sounds/brick.wav");
 }
 
+Block::Block(const Reader& lisp, std::string sprite_file) :
+  sprite(),
+  bouncing(false),
+  breaking(false),
+  bounce_dir(0),
+  bounce_offset(0),
+  original_y(-1)
+{
+  lisp.get("x", bbox.p1.x);
+  lisp.get("y", bbox.p1.y);
+
+  std::string sf = sprite_file;
+  lisp.get("sprite", sf);
+  sprite = SpriteManager::current()->create(sf);
+
+  bbox.set_size(32, 32.1f);
+  set_group(COLGROUP_STATIC);
+  SoundManager::current()->preload("sounds/upgrade.wav");
+  SoundManager::current()->preload("sounds/brick.wav");
+}
+
 Block::~Block()
 {
 }
@@ -54,7 +77,7 @@ Block::collision(GameObject& other, const CollisionHit& )
 {
   Player* player = dynamic_cast<Player*> (&other);
   if(player) {
-    if(player->get_bbox().get_top() > get_bbox().get_bottom() - SHIFT_DELTA) {
+    if(player->get_bbox().get_top() > bbox.get_bottom() - SHIFT_DELTA) {
       hit(*player);
     }
   }
@@ -66,7 +89,7 @@ Block::collision(GameObject& other, const CollisionHit& )
   Portable* portable = dynamic_cast<Portable*> (&other);
   MovingObject* moving_object = dynamic_cast<MovingObject*> (&other);
   bool is_portable = ((portable != 0) && portable->is_portable());
-  bool hit_mo_from_below = ((moving_object == 0) || (moving_object->get_bbox().get_bottom() < (get_bbox().get_top() + SHIFT_DELTA)));
+  bool hit_mo_from_below = ((moving_object == 0) || (moving_object->get_bbox().get_bottom() < (bbox.get_top() + SHIFT_DELTA)));
   if(bouncing && !is_portable && hit_mo_from_below) {
 
     // Badguys get killed
@@ -134,7 +157,7 @@ Block::start_bounce(GameObject* hitter)
   MovingObject* hitter_mo = dynamic_cast<MovingObject*>(hitter);
   if (hitter_mo) {
     float center_of_hitter = hitter_mo->get_bbox().get_middle().x;
-    float offset = (get_bbox().get_middle().x - center_of_hitter)*2 / get_bbox().get_width();
+    float offset = (bbox.get_middle().x - center_of_hitter)*2 / bbox.get_width();
     sprite->set_angle(BUMP_ROTATION_ANGLE*offset);
   }
 }
