@@ -30,7 +30,8 @@ class Sprite;
 class BouncyCoin : public GameObject
 {
 public:
-  BouncyCoin(const Vector& pos, bool emerge=false);
+  BouncyCoin(const Vector& pos, bool emerge = false,
+             const std::string& sprite_path = "images/objects/coin/coin.sprite");
   ~BouncyCoin();
   virtual void update(float elapsed_time);
   virtual void draw(DrawingContext& context);
