@@ -18,6 +18,7 @@
 
 #include "audio/sound_manager.hpp"
 #include "badguy/badguy.hpp"
+#include "lisp/list_iterator.hpp"
 #include "object/bouncy_coin.hpp"
 #include "object/explosion.hpp"
 #include "object/flower.hpp"
@@ -39,6 +40,17 @@ Brick::Brick(const Vector& pos, int data, const std::string& spriteName)
     breakable = true;
 }
 
+Brick::Brick(const Reader& lisp) :
+  Block(lisp, "images/objects/bonus_block/brick.sprite"),
+  breakable(),
+  coin_counter(0)
+{
+  lisp.get("breakable",breakable);
+  if (!breakable) {
+    coin_counter = 5;
+  }
+}
+
 void
 Brick::hit(Player& player)
 {
@@ -62,14 +74,14 @@ Brick::collision(GameObject& other, const CollisionHit& hit_){
     // hit contains no information for collisions with blocks.
     // Badguy's bottom has to be below the top of the brick
     // SHIFT_DELTA is required to slide over one tile gaps.
-    if( badguy->can_break() && ( badguy->get_bbox().get_bottom() > get_bbox().get_top() + SHIFT_DELTA ) ){
+    if( badguy->can_break() && ( badguy->get_bbox().get_bottom() > bbox.get_top() + SHIFT_DELTA ) ){
       try_break(player);
     }
   }
   Portable* portable = dynamic_cast<Portable*> (&other);
   if(portable) {
     MovingObject* moving = dynamic_cast<MovingObject*> (&other);
-    if(moving->get_bbox().get_top() > get_bbox().get_bottom() - SHIFT_DELTA) {
+    if(moving->get_bbox().get_top() > bbox.get_bottom() - SHIFT_DELTA) {
       try_break(player);
     }
   }
