@@ -18,6 +18,7 @@
 #define HEADER_SUPERTUX_OBJECT_COIN_HPP
 
 #include "object/moving_sprite.hpp"
+#include "supertux/physic.hpp"
 
 class Path;
 class PathWalker;
@@ -36,10 +37,24 @@ public:
   virtual void update(float elapsed_time);
 
 private:
-  boost::shared_ptr<Path> path;
-  boost::shared_ptr<PathWalker> walker;
+  std::shared_ptr<Path> path;
+  std::shared_ptr<PathWalker> walker;
   Vector offset;
   bool from_tilemap;
+  Physic physic;
+};
+
+class HeavyCoin : public Coin
+{
+public:
+  HeavyCoin(const Vector& pos, const Vector& init_velocity);
+  HeavyCoin(const Reader& reader);
+
+  virtual void update(float elapsed_time);
+  virtual void collision_solid(const CollisionHit& hit);
+
+private:
+  Physic physic;
 };
 
 #endif
