@@ -71,11 +71,11 @@ Flower::draw(DrawingContext& context)
   //Draw the Sprite.
   sprite->draw(context, get_pos(), LAYER_OBJECTS, drawing_effect);
   //Draw the light when dark
-  context.get_light( get_bbox().get_middle(), &light );
+  context.get_light( bbox.get_middle(), &light );
   if (light.red + light.green + light.blue < 3.0){
     context.push_target();
     context.set_target(DrawingContext::LIGHTMAP);
-    lightsprite->draw(context, get_bbox().get_middle(), 0);
+    lightsprite->draw(context, bbox.get_middle(), 0);
     context.pop_target();
   }
 }
