@@ -39,6 +39,8 @@ private:
 private:
   Flower(const Flower&);
   Flower& operator=(const Flower&);
+  Color light;
+  SpritePtr lightsprite;
 
   friend class FlipLevelTransformer;
 };
