@@ -34,6 +34,7 @@ public:
   virtual HitResponse collision(GameObject& other, const CollisionHit& hit);
   virtual void collision_solid(const CollisionHit& hit);
   virtual void update(float elapsed_time);
+  virtual void draw(DrawingContext& context);
 
 #if 0
   const Vector& get_speed() const
@@ -56,6 +57,11 @@ protected:
   Player* get_nearest_player();
   bool found_victim();
   void set_state(IceCrusherState state, bool force = false);
+  Vector eye_position(bool right);
+
+  SpritePtr lefteye;
+  SpritePtr righteye;
+  SpritePtr whites;
 
 private:
   enum IceCrusherSize {
