@@ -26,6 +26,7 @@
 #include "supertux/object_factory.hpp"
 #include "supertux/resources.hpp"
 #include "supertux/sector.hpp"
+#include "util/log.hpp"
 #include "util/reader.hpp"
 #include "video/drawing_context.hpp"
 
@@ -39,7 +40,10 @@ LevelTime::LevelTime(const Reader& reader) :
 {
   reader.get("name", name);
   reader.get("time", time_left);
-  if(time_left <= 0) throw std::runtime_error("No or invalid leveltime specified");
+  if(time_left <= 0) {
+    log_warning << "No or invalid leveltime specified." << std::endl;
+    remove_me();
+  }
   time_surface = Surface::create("images/engine/hud/time-0.png");
 }
 
@@ -115,7 +119,7 @@ LevelTime::stop()
 }
 
 float
-LevelTime::get_time()
+LevelTime::get_time() const
 {
   return time_left;
 }
