@@ -18,12 +18,12 @@
 #include "sprite/sprite.hpp"
 #include "sprite/sprite_manager.hpp"
 
-Light::Light(const Vector& center, const Color& color) : 
-  position(center), 
-  color(color),
+Light::Light(const Vector& center, const Color& color_) :
+  position(center),
+  color(color_),
   sprite()
 {
-  sprite = sprite_manager->create("images/objects/lightmap_light/lightmap_light.sprite");
+  sprite = SpriteManager::current()->create("images/objects/lightmap_light/lightmap_light.sprite");
 }
 
 Light::~Light()
