@@ -262,7 +262,7 @@ Player::unexpose(HSQUIRRELVM vm, SQInteger table_idx)
 }
 
 float
-Player::get_speedlimit()
+Player::get_speedlimit() const
 {
   return speedlimit;
 }
@@ -486,13 +486,21 @@ Player::update(float elapsed_time)
 }
 
 bool
-Player::on_ground()
+Player::slightly_above_ground() const
 {
-  return on_ground_flag;
+  float abs_vy = std::abs(physic.get_velocity_y());
+  float ground_y_delta = std::abs(last_ground_y - get_pos().y);
+  return (abs_vy == 15.625 || abs_vy == 31.25) && ground_y_delta < 0.85;
 }
 
 bool
-Player::is_big()
+Player::on_ground() const
+{
+  return on_ground_flag || slightly_above_ground();
+}
+
+bool
+Player::is_big() const
 {
   if(player_status->bonus == NO_BONUS)
     return false;
@@ -585,7 +593,7 @@ Player::handle_horizontal_input()
       // dust some particles
       Sector::current()->add_object(
         std::make_shared<Particles>(
-          Vector(dir == LEFT ? get_bbox().p2.x : get_bbox().p1.x, get_bbox().p2.y),
+          Vector(dir == LEFT ? bbox.p2.x : bbox.p1.x, bbox.p2.y),
           dir == LEFT ? 50 : -70, dir == LEFT ? 70 : -50, 260, 280,
           Vector(0, 300), 3, Color(.4f, .4f, .4f), 3, .8f, LAYER_OBJECTS+1));
 
@@ -885,7 +893,7 @@ Player::handle_input()
     stone = false;
     for (int i = 0; i < 8; i++)
     {
-      Vector ppos = Vector(get_bbox().get_left() + 8 + 16*((int)i/4), get_bbox().get_top() + 16*(i%4));
+      Vector ppos = Vector(bbox.get_left() + 8 + 16*((int)i/4), bbox.get_top() + 16*(i%4));
       float grey = graphicsRandom.randf(.4f, .8f);
       Color pcolor = Color(grey, grey, grey);
       Sector::current()->add_object(std::make_shared<Particles>(ppos, -60, 240, 42, 81, Vector(0, 500),
@@ -950,8 +958,8 @@ Player::position_grabbed_object()
   assert(moving_object);
 
   // Position where we will hold the lower-inner corner
-  Vector pos(get_bbox().get_left() + get_bbox().get_width()/2,
-      get_bbox().get_top() + get_bbox().get_height()*0.66666);
+  Vector pos(bbox.get_left() + bbox.get_width()/2,
+      bbox.get_top() + bbox.get_height()*0.66666);
 
   // Adjust to find the grabbed object's upper-left corner
   if (dir == LEFT)
@@ -1031,35 +1039,46 @@ Player::add_coins(int count)
 }
 
 int
-Player::get_coins()
+Player::get_coins() const
 {
   return player_status->coins;
 }
 
+BonusType
+Player::string_to_bonus(const std::string& bonus) {
+  BonusType type = NO_BONUS;
+
+  if(bonus == "grow") {
+    type = GROWUP_BONUS;
+  } else if(bonus == "fireflower") {
+    type = FIRE_BONUS;
+  } else if(bonus == "iceflower") {
+    type = ICE_BONUS;
+  } else if(bonus == "airflower") {
+    type = AIR_BONUS;
+  } else if(bonus == "earthflower") {
+    type = EARTH_BONUS;
+  } else if(bonus == "none") {
+    type = NO_BONUS;
+  } else {
+    std::ostringstream msg;
+    msg << "Unknown bonus type "  << bonus;
+    throw std::runtime_error(msg.str());
+  }
+
+  return type;
+}
+
 bool
 Player::add_bonus(const std::string& bonustype)
 {
-  BonusType type = NO_BONUS;
+  return add_bonus( string_to_bonus(bonustype) );
+}
 
-  if(bonustype == "grow") {
-    type = GROWUP_BONUS;
-  } else if(bonustype == "fireflower") {
-    type = FIRE_BONUS;
-  } else if(bonustype == "iceflower") {
-    type = ICE_BONUS;
-  } else if(bonustype == "airflower") {
-    type = AIR_BONUS;
-  } else if(bonustype == "earthflower") {
-    type = EARTH_BONUS;
-  } else if(bonustype == "none") {
-    type = NO_BONUS;
-  } else {
-    std::ostringstream msg;
-    msg << "Unknown bonus type "  << bonustype;
-    throw std::runtime_error(msg.str());
-  }
-
-  return add_bonus(type);
+bool
+Player::set_bonus(const std::string& bonustype)
+{
+  return set_bonus( string_to_bonus(bonustype) );
 }
 
 bool
@@ -1082,6 +1101,10 @@ Player::add_bonus(BonusType type, bool animate)
 bool
 Player::set_bonus(BonusType type, bool animate)
 {
+  if(dying) {
+    return false;
+  }
+
   if((player_status->bonus == NO_BONUS) && (type != NO_BONUS)) {
     if (!adjust_height(BIG_TUX_HEIGHT)) {
       log_debug << "Can't adjust Tux height" << std::endl;
@@ -1095,51 +1118,46 @@ Player::set_bonus(BonusType type, bool animate)
   }
 
   if (type == NO_BONUS) {
+    if (!adjust_height(SMALL_TUX_HEIGHT)) {
+      log_debug << "Can't adjust Tux height" << std::endl;
+      return false;
+    }
     if (does_buttjump) does_buttjump = false;
   }
 
   if ((type == NO_BONUS) || (type == GROWUP_BONUS)) {
+    Vector ppos = Vector((bbox.p1.x + bbox.p2.x) / 2, bbox.p1.y);
+    Vector pspeed = Vector(((dir == LEFT) ? 100 : -100), -300);
+    Vector paccel = Vector(0, 1000);
+    std::string action = (dir == LEFT) ? "left" : "right";
+    std::string particle_name = "";
+
     if ((player_status->bonus == FIRE_BONUS) && (animate)) {
       // visually lose helmet
-      Vector ppos = Vector((bbox.p1.x + bbox.p2.x) / 2, bbox.p1.y);
-      Vector pspeed = Vector(((dir==LEFT) ? +100 : -100), -300);
-      Vector paccel = Vector(0, 1000);
-      std::string action = (dir==LEFT)?"left":"right";
       if (g_config->christmas_mode) {
-        Sector::current()->add_object(std::make_shared<SpriteParticle>("images/objects/particles/santatux-hat.sprite", action, ppos,ANCHOR_TOP, pspeed, paccel, LAYER_OBJECTS-1)); 
+        particle_name = "santatux-hat";
       }
       else {
-        Sector::current()->add_object(std::make_shared<SpriteParticle>("images/objects/particles/firetux-helmet.sprite", action, ppos, ANCHOR_TOP, pspeed, paccel, LAYER_OBJECTS-1));
+        particle_name = "firetux-helmet";
       }
-      if (climbing) stop_climbing(*climbing);
     }
     if ((player_status->bonus == ICE_BONUS) && (animate)) {
       // visually lose cap
-      Vector ppos = Vector((bbox.p1.x + bbox.p2.x) / 2, bbox.p1.y);
-      Vector pspeed = Vector(((dir==LEFT) ? +100 : -100), -300);
-      Vector paccel = Vector(0, 1000);
-      std::string action = (dir==LEFT)?"left":"right";
-      Sector::current()->add_object(std::make_shared<SpriteParticle>("images/objects/particles/icetux-cap.sprite", action, ppos, ANCHOR_TOP, pspeed, paccel, LAYER_OBJECTS-1));
-      if (climbing) stop_climbing(*climbing);
+      particle_name = "icetux-cap";
     }
     if ((player_status->bonus == AIR_BONUS) && (animate)) {
       // visually lose hat
-      Vector ppos = Vector((bbox.p1.x + bbox.p2.x) / 2, bbox.p1.y);
-      Vector pspeed = Vector(((dir==LEFT) ? +100 : -100), -300);
-      Vector paccel = Vector(0, 1000);
-      std::string action = (dir==LEFT)?"left":"right";
-      Sector::current()->add_object(std::make_shared<SpriteParticle>("images/objects/particles/airtux-hat.sprite", action, ppos, ANCHOR_TOP, pspeed, paccel, LAYER_OBJECTS-1));
-      if (climbing) stop_climbing(*climbing);
+      particle_name = "airtux-hat";
     }
     if ((player_status->bonus == EARTH_BONUS) && (animate)) {
       // visually lose hard-hat
-      Vector ppos = Vector((bbox.p1.x + bbox.p2.x) / 2, bbox.p1.y);
-      Vector pspeed = Vector(((dir==LEFT) ? +100 : -100), -300);
-      Vector paccel = Vector(0, 1000);
-      std::string action = (dir==LEFT)?"left":"right";
-      Sector::current()->add_object(std::make_shared<SpriteParticle>("images/objects/particles/earthtux-hardhat.sprite", action, ppos, ANCHOR_TOP, pspeed, paccel, LAYER_OBJECTS-1));
-      if (climbing) stop_climbing(*climbing);
+      particle_name = "earthtux-hardhat";
     }
+    if(!particle_name.empty() && animate) {
+      Sector::current()->add_object(std::make_shared<SpriteParticle>("images/objects/particles/" + particle_name + ".sprite", action, ppos, ANCHOR_TOP, pspeed, paccel, LAYER_OBJECTS - 1));
+    }
+    if(climbing) stop_climbing(*climbing);
+
     player_status->max_fire_bullets = 0;
     player_status->max_ice_bullets = 0;
     player_status->max_air_time = 0;
@@ -1165,7 +1183,7 @@ Player::set_visible(bool visible_)
 }
 
 bool
-Player::get_visible()
+Player::get_visible() const
 {
   return visible;
 }
@@ -1183,10 +1201,10 @@ Player::draw(DrawingContext& context)
     return;
 
   // if Tux is above camera, draw little "air arrow" to show where he is x-wise
-  if (Sector::current() && Sector::current()->camera && (get_bbox().p2.y - 16 < Sector::current()->camera->get_translation().y)) {
-    float px = get_pos().x + (get_bbox().p2.x - get_bbox().p1.x - airarrow.get()->get_width()) / 2;
+  if (Sector::current() && Sector::current()->camera && (bbox.p2.y - 16 < Sector::current()->camera->get_translation().y)) {
+    float px = bbox.p1.x + (bbox.p2.x - bbox.p1.x - airarrow.get()->get_width()) / 2;
     float py = Sector::current()->camera->get_translation().y;
-    py += std::min(((py - (get_bbox().p2.y + 16)) / 4), 16.0f);
+    py += std::min(((py - (bbox.p2.y + 16)) / 4), 16.0f);
     context.draw_surface(airarrow, Vector(px, py), LAYER_HUD - 1);
   }
 
@@ -1326,7 +1344,7 @@ Player::draw(DrawingContext& context)
   }
   else {
     if(dying)
-      sprite->draw(context, get_pos(), Sector::current()->get_foremost_layer() + 1);
+      sprite->draw(context, get_pos(), Sector::current()->get_foremost_layer());
     else
       sprite->draw(context, get_pos(), LAYER_OBJECTS + 1);
 
@@ -1383,11 +1401,11 @@ Player::collision_solid(const CollisionHit& hit)
       physic.set_velocity_y(-300);
       on_ground_flag = false;
       Sector::current()->add_object(std::make_shared<Particles>(
-                                      Vector(get_bbox().p2.x, get_bbox().p2.y),
+                                      bbox.p2,
                                       50, 70, 260, 280, Vector(0, 300), 3,
                                       Color(.4f, .4f, .4f), 3, .8f, LAYER_OBJECTS+1));
       Sector::current()->add_object(std::make_shared<Particles>(
-                                      Vector(get_bbox().p1.x, get_bbox().p2.y),
+                                      Vector(bbox.p1.x, bbox.p2.y),
                                       -70, -50, 260, 280, Vector(0, 300), 3,
                                       Color(.4f, .4f, .4f), 3, .8f, LAYER_OBJECTS+1));
       Sector::current()->camera->shake(.1f, 0, 5);
@@ -1398,7 +1416,7 @@ Player::collision_solid(const CollisionHit& hit)
       physic.set_velocity_y(.2f);
   }
 
-  if(hit.left || hit.right) {
+  if((hit.left || hit.right) && hit.slope_normal.x == 0) {
     physic.set_velocity_x(0);
   }
 
@@ -1576,10 +1594,10 @@ Player::check_bounds()
     set_pos(Vector(0, get_pos().y));
   }
 
-  if (get_bbox().get_right() > Sector::current()->get_width()) {
+  if (bbox.get_right() > Sector::current()->get_width()) {
     // Lock Tux to the size of the level, so that he doesn't fall off
     // the right side
-    set_pos(Vector(Sector::current()->get_width() - get_bbox().get_width(), get_pos().y));
+    set_pos(Vector(Sector::current()->get_width() - bbox.get_width(), bbox.p1.y));
   }
 
   /* fallen out of the level? */
@@ -1609,7 +1627,7 @@ Player::add_velocity(const Vector& velocity, const Vector& end_speed)
 }
 
 Vector
-Player::get_velocity()
+Player::get_velocity() const
 {
   return physic.get_velocity();
 }
@@ -1688,7 +1706,7 @@ Player::set_edit_mode(bool enable)
 void
 Player::start_climbing(Climbable& climbable)
 {
-  if (climbing || !&climbable) return;
+  if (climbing) return;
 
   climbing = &climbable;
   physic.enable_gravity(false);
