@@ -68,7 +68,7 @@ PneumaticPlatform::collision(GameObject& other, const CollisionHit& )
   // somehow the hit parameter does not get filled in, so to determine (hit.top == true) we do this:
   MovingObject* mo = dynamic_cast<MovingObject*>(&other);
   if (!mo) return FORCE_MOVE;
-  if ((mo->get_bbox().p2.y) > (get_bbox().p1.y + 2)) return FORCE_MOVE;
+  if ((mo->get_bbox().p2.y) > (bbox.p1.y + 2)) return FORCE_MOVE;
 
   Player* pl = dynamic_cast<Player*>(mo);
   if (pl) {
@@ -101,10 +101,10 @@ PneumaticPlatform::update(float elapsed_time)
     contacts.clear();
     slave->contacts.clear();
 
-    speed_y += ((float)contact_diff * elapsed_time) * 128.0f;
-    speed_y -= (offset_y * elapsed_time * 0.5f);
+    speed_y += ((float)contact_diff * elapsed_time) * 12.8f;
+    speed_y -= (offset_y * elapsed_time * 0.05f);
     speed_y *= 1 - elapsed_time;
-    offset_y += speed_y * elapsed_time;
+    offset_y += speed_y * elapsed_time * Sector::current()->get_gravity();
     if (offset_y < -256) { offset_y = -256; speed_y = 0; }
     if (offset_y > 256) { offset_y = 256; speed_y = -0; }
     movement = Vector(0, (start_y + offset_y) - get_pos().y);
