@@ -42,6 +42,7 @@ PowerUp::PowerUp(const Reader& lisp) :
   physic.enable_gravity(true);
   SoundManager::current()->preload("sounds/grow.ogg");
   SoundManager::current()->preload("sounds/fire-flower.wav");
+  SoundManager::current()->preload("sounds/gulp.wav");
   //set default light for glow effect for standard sprites
   lightsprite->set_blend(Blend(GL_SRC_ALPHA, GL_ONE));
   lightsprite->set_color(Color(0.0f, 0.0f, 0.0f));
@@ -108,6 +109,11 @@ PowerUp::collision(GameObject& other, const CollisionHit&)
   if(player == 0)
     return FORCE_MOVE;
 
+  if (sprite_name == "images/powerups/potions/blue-potion.sprite" ||
+      sprite_name == "images/powerups/potions/red-potion.sprite") {
+      SoundManager::current()->play("sounds/gulp.wav");
+  }
+
   if (script != "") {
     std::istringstream stream(script);
     Sector::current()->run_script(stream, "powerup-script");
@@ -155,7 +161,7 @@ PowerUp::update(float elapsed_time)
     movement = physic.get_movement(elapsed_time);
   //Stars sparkle when close to Tux
   if (sprite_name == "images/powerups/star/star.sprite"){
-    Player* player = Sector::current()->get_nearest_player (this->get_bbox ());
+    Player* player = Sector::current()->get_nearest_player(bbox);
     if (player) {
       float disp_x = player->get_bbox().p1.x - bbox.p1.x;
       float disp_y = player->get_bbox().p1.y - bbox.p1.y;
@@ -185,7 +191,7 @@ PowerUp::draw(DrawingContext& context){
   //Draw the Sprite.
   sprite->draw(context, get_pos(), layer);
   //Draw light when dark for defaults
-  context.get_light( get_bbox().get_middle(), &light );
+  context.get_light( bbox.get_middle(), &light );
   if (light.red + light.green + light.blue < 3.0){
     //Stars are brighter
     if (sprite_name == "images/powerups/star/star.sprite") {
@@ -193,7 +199,7 @@ PowerUp::draw(DrawingContext& context){
     }
     context.push_target();
     context.set_target(DrawingContext::LIGHTMAP);
-    lightsprite->draw(context, get_bbox().get_middle(), 0);
+    lightsprite->draw(context, bbox.get_middle(), 0);
     context.pop_target();
   }
 }
