@@ -23,8 +23,10 @@ class PowerUp : public MovingSprite
 {
 public:
   PowerUp(const Reader& lisp);
+  PowerUp(const Vector& pos, const std::string& sprite_name);
 
   virtual void update(float elapsed_time);
+  virtual void draw(DrawingContext& context);
   virtual void collision_solid(const CollisionHit& hit);
   virtual HitResponse collision(GameObject& other, const CollisionHit& hit);
 
@@ -32,6 +34,8 @@ private:
   Physic physic;
   std::string script;
   bool no_physics;
+  Color light;
+  SpritePtr lightsprite;
 };
 
 #endif
