@@ -19,6 +19,7 @@
 #include "math/random_generator.hpp"
 #include "object/camera.hpp"
 #include "object/rainsplash.hpp"
+#include "supertux/sector.hpp"
 #include "util/reader.hpp"
 
 RainParticleSystem::RainParticleSystem()
@@ -39,7 +40,6 @@ RainParticleSystem::RainParticleSystem()
     do {
       particle->speed = (rainsize+1)*45 + graphicsRandom.randf(3.6);
     } while(particle->speed < 1);
-    particle->speed *= 10; // gravity
 
     particles.push_back(particle);
   }
@@ -61,7 +61,7 @@ void RainParticleSystem::update(float elapsed_time)
   for(
     i = particles.begin(); i != particles.end(); ++i) {
     RainParticle* particle = (RainParticle*) *i;
-    float movement = particle->speed * elapsed_time;
+    float movement = particle->speed * elapsed_time * Sector::current()->get_gravity();
     float abs_x = Sector::current()->camera->get_translation().x;
     float abs_y = Sector::current()->camera->get_translation().y;
     particle->pos.y += movement;
