@@ -18,13 +18,11 @@
 
 RainSplash::RainSplash(Vector pos, bool vertical) :
   sprite(),
-  position(),
-  frame()
+  position(pos),
+  frame(0)
 {
-  frame = 0;
-  position = pos;
-  if (vertical) sprite = sprite_manager->create("images/objects/particles/rainsplash-vertical.sprite");
-  else sprite = sprite_manager->create("images/objects/particles/rainsplash.sprite");
+  if (vertical) sprite = SpriteManager::current()->create("images/objects/particles/rainsplash-vertical.sprite");
+  else sprite = SpriteManager::current()->create("images/objects/particles/rainsplash.sprite");
 }
 
 RainSplash::~RainSplash() {
