@@ -40,6 +40,9 @@ private:
   Vector velocity;
   Vector acceleration;
   int drawing_layer;
+  Color light;
+  SpritePtr lightsprite;
+  bool glow;
 
 private:
   SpriteParticle(const SpriteParticle&);
