@@ -22,9 +22,16 @@
 
 class IFileStream : public std::istream
 {
+protected:
+  std::streambuf *sb;
+
 public:
   IFileStream(const std::string& filename);
   ~IFileStream();
+
+private:
+  IFileStream(const IFileStream&) = delete;
+  IFileStream& operator=(const IFileStream&) = delete;
 };
 
 #endif
