@@ -22,13 +22,14 @@
 #include "physfs/ofile_streambuf.hpp"
 
 OFileStream::OFileStream(const std::string& filename) :
-  std::ostream(new OFileStreambuf(filename))
+  std::ostream(nullptr), sb(new OFileStreambuf(filename))
 {
+  init(sb);
 }
 
 OFileStream::~OFileStream()
 {
-  delete rdbuf();
+  delete sb;
 }
 
 #endif
