@@ -22,9 +22,16 @@
 
 class OFileStream : public std::ostream
 {
+protected:
+  std::streambuf *sb;
+
 public:
   OFileStream(const std::string& filename);
   ~OFileStream();
+
+private:
+  OFileStream(const OFileStream&) = delete;
+  OFileStream& operator=(const OFileStream&) = delete;
 };
 
 #endif
