@@ -1,5 +1,5 @@
 //  SuperTux
-//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmx.de>
+//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmail.com>
 //
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -37,10 +37,10 @@ PhysFSFileSystem::open_directory(const std::string& pathname)
   return files;
 }
 
-std::auto_ptr<std::istream>
+std::unique_ptr<std::istream>
 PhysFSFileSystem::open_file(const std::string& filename)
 {
-  return std::auto_ptr<std::istream>(new IFileStream(filename));
+  return std::unique_ptr<std::istream>(new IFileStream(filename));
 }
 
 /* EOF */
