@@ -1,5 +1,5 @@
 //  SuperTux
-//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmx.de>
+//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmail.com>
 //
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ public:
   PhysFSFileSystem();
 
   std::vector<std::string>    open_directory(const std::string& pathname);
-  std::auto_ptr<std::istream> open_file(const std::string& filename);
+  std::unique_ptr<std::istream> open_file(const std::string& filename);
 };
 
 #endif
