@@ -76,17 +76,26 @@ void exit_screen()
 
 void fadeout_screen(float seconds)
 {
-  ScreenManager::current()->set_screen_fade(std::unique_ptr<ScreenFade>(new FadeOut(seconds)));
+  if(g_config->transitions_enabled)
+  {
+    ScreenManager::current()->set_screen_fade(std::unique_ptr<ScreenFade>(new FadeOut(seconds)));
+  }
 }
 
 void shrink_screen(float dest_x, float dest_y, float seconds)
 {
-  ScreenManager::current()->set_screen_fade(std::unique_ptr<ScreenFade>(new ShrinkFade(Vector(dest_x, dest_y), seconds)));
+  if(g_config->transitions_enabled)
+  {
+    ScreenManager::current()->set_screen_fade(std::unique_ptr<ScreenFade>(new ShrinkFade(Vector(dest_x, dest_y), seconds)));
+  }
 }
 
 void abort_screenfade()
 {
-  ScreenManager::current()->set_screen_fade(std::unique_ptr<ScreenFade>());
+  if(g_config->transitions_enabled)
+  {
+    ScreenManager::current()->set_screen_fade(std::unique_ptr<ScreenFade>());
+  }
 }
 
 std::string translate(const std::string& text)
@@ -94,6 +103,11 @@ std::string translate(const std::string& text)
   return g_dictionary_manager->get_dictionary().translate(text);
 }
 
+std::string _(const std::string& text)
+{
+  return translate(text);
+}
+
 void display_text_file(const std::string& filename)
 {
   ScreenManager::current()->push_screen(std::unique_ptr<Screen>(new TextScroller(filename)));
@@ -185,6 +199,20 @@ void save_state()
   }
 }
 
+void load_state()
+{
+  using worldmap::WorldMap;
+
+  if (!WorldMap::current())
+  {
+    throw std::runtime_error("Can't save state without active Worldmap");
+  }
+  else
+  {
+    WorldMap::current()->load_state();
+  }
+}
+
 // not added to header, function to only be used by others
 // in this file
 bool validate_sector_player()
