@@ -95,6 +95,7 @@ void abort_screenfade();
  * files)
  */
 std::string translate(const std::string& text);
+std::string _(const std::string& text);
 
 /**
  * Load a script file and executes it. This is typically used to import
@@ -103,10 +104,15 @@ std::string translate(const std::string& text);
 void import(HSQUIRRELVM v, const std::string& filename);
 
 /**
- * Save world state to savegame
+ * Save world state to scripting table
  */
 void save_state();
 
+/**
+ * Load world state from scripting table
+ */
+void load_state();
+
 /**
  * enable/disable drawing of collision rectangles
  */
