@@ -68,7 +68,7 @@ private:
 
   void parse_action(const Reader& lispreader, const std::string& basedir);
   /** Get an action */
-  const Action* get_action(const std::string& act);
+  const Action* get_action(const std::string& act) const;
 
   Actions actions;
   std::string name;
