@@ -40,6 +40,7 @@ public:
 
 public:
   std::list<std::string> m_lines; /**< backbuffer of lines sent to the console. New lines get added to front. */
+  Console* m_console;
 
 public:
   ConsoleBuffer();
@@ -49,6 +50,8 @@ public:
 
   void flush(ConsoleStreamBuffer& buffer); /**< act upon changes in a ConsoleStreamBuffer */
 
+  void set_console(Console* console);
+
 private:
   ConsoleBuffer(const ConsoleBuffer&) = delete;
   ConsoleBuffer& operator=(const ConsoleBuffer&) = delete;
@@ -71,7 +74,7 @@ public:
   void show_history(int offset); /**< move @c offset lines forward through history; Negative offset moves backward */
   void move_cursor(int offset); /**< move the cursor @c offset chars to the right; Negative offset moves backward; 0xFFFF moves to the end */
 
-  void draw(DrawingContext& context); /**< draw the console in a DrawingContext */
+  void draw(DrawingContext& context) const; /**< draw the console in a DrawingContext */
   void update(float elapsed_time);
 
   void show(); /**< display the console */
@@ -79,7 +82,7 @@ public:
   void hide(); /**< hide the console */
   void toggle(); /**< display the console if hidden, hide otherwise */
 
-  bool hasFocus(); /**< true if characters should be sent to the console instead of their normal target */
+  bool hasFocus() const; /**< true if characters should be sent to the console instead of their normal target */
 
 private:
   ConsoleBuffer& m_buffer;
