@@ -27,13 +27,13 @@ class FadeOut : public ScreenFade
 {
 public:
   FadeOut(float fade_time, Color dest_color = Color(0, 0, 0));
-  virtual ~FadeOut();
+  ~FadeOut();
 
-  virtual void update(float elapsed_time);
-  virtual void draw(DrawingContext& context);
+  void update(float elapsed_time);
+  void draw(DrawingContext& context);
 
   /// returns true if the effect is completed
-  virtual bool done();
+  bool done() const;
 
 private:
   Color color;
