@@ -33,6 +33,7 @@
 #include "scripting/scripting.hpp"
 #include "scripting/squirrel_util.hpp"
 #include "scripting/squirrel_util.hpp"
+#include "supertux/fadein.hpp"
 #include "supertux/gameconfig.hpp"
 #include "supertux/globals.hpp"
 #include "supertux/levelintro.hpp"
@@ -53,6 +54,7 @@
 #endif
 
 GameSession::GameSession(const std::string& levelfile_, Savegame& savegame, Statistics* statistics) :
+  reset_button(false),
   level(),
   statistics_backdrop(Surface::create("images/engine/menu/score-backdrop.png")),
   scripts(),
@@ -80,12 +82,24 @@ GameSession::GameSession(const std::string& levelfile_, Savegame& savegame, Stat
   bonus_at_start(),
   max_fire_bullets_at_start(),
   max_ice_bullets_at_start(),
-  active(false)
+  active(false),
+  end_seq_started(false)
 {
   if (restart_level() != 0)
     throw std::runtime_error ("Initializing the level failed.");
 }
 
+void
+GameSession::reset_level()
+{
+  currentsector->player->set_bonus(bonus_at_start);
+  PlayerStatus *currentStatus = m_savegame.get_player_status();
+  currentStatus->coins = coins_at_start;
+  currentStatus->max_fire_bullets = max_fire_bullets_at_start;
+  currentStatus->max_ice_bullets = max_ice_bullets_at_start;
+  reset_sector = "";
+}
+
 int
 GameSession::restart_level(bool after_death)
 {
@@ -182,7 +196,7 @@ GameSession::record_demo(const std::string& filename)
 }
 
 int
-GameSession::get_demo_random_seed(const std::string& filename)
+GameSession::get_demo_random_seed(const std::string& filename) const
 {
   std::istream* test_stream = new std::ifstream(filename.c_str());
   if(test_stream->good()) {
@@ -258,6 +272,7 @@ GameSession::toggle_pause()
     speed_before_pause = ScreenManager::current()->get_speed();
     ScreenManager::current()->set_speed(0);
     MenuManager::instance().set_menu(MenuStorage::GAME_MENU);
+    SoundManager::current()->pause_sounds();
     SoundManager::current()->pause_music();
     game_pause = true;
   }
@@ -275,6 +290,7 @@ GameSession::abort_level()
   currentStatus->coins = coins_at_start;
   currentStatus->max_fire_bullets = max_fire_bullets_at_start;
   currentStatus->max_ice_bullets = max_ice_bullets_at_start;
+  SoundManager::current()->stop_sounds();
 }
 
 bool
@@ -423,8 +439,13 @@ GameSession::setup()
   if ((!levelintro_shown) && (total_stats_to_be_collected > 0)) {
     levelintro_shown = true;
     active = false;
-    ScreenManager::current()->push_screen(std::unique_ptr<Screen>(new LevelIntro(level.get(), best_level_statistics)));
+    ScreenManager::current()->push_screen(std::unique_ptr<Screen>(new LevelIntro(level.get(), best_level_statistics, m_savegame.get_player_status())));
   }
+  if(g_config->transitions_enabled)
+  {
+    ScreenManager::current()->set_screen_fade(std::unique_ptr<ScreenFade>(new FadeIn(1)));
+  }
+  end_seq_started = false;
 }
 
 void
@@ -463,6 +484,7 @@ GameSession::update(float elapsed_time)
   if (game_pause && !MenuManager::instance().is_active()) {
     ScreenManager::current()->set_speed(speed_before_pause);
     SoundManager::current()->resume_music();
+    SoundManager::current()->resume_sounds();
     game_pause = false;
   }
 
@@ -503,7 +525,7 @@ GameSession::update(float elapsed_time)
 
   if(currentsector == NULL)
     return;
-  
+
   // update sounds
   if (currentsector->camera) SoundManager::current()->set_listener_position(currentsector->camera->get_center());
 
@@ -521,11 +543,20 @@ GameSession::update(float elapsed_time)
   } else if(currentsector->get_music_type() != LEVEL_MUSIC) {
     currentsector->play_music(LEVEL_MUSIC);
   }
+  if (reset_button) {
+    reset_button = false;
+    reset_level();
+    restart_level();
+  }
 }
 
 void
 GameSession::finish(bool win)
 {
+  if(end_seq_started)
+    return;
+  end_seq_started = true;
+
   using namespace worldmap;
 
   if (edit_mode) {
@@ -563,7 +594,7 @@ GameSession::set_reset_point(const std::string& sector, const Vector& pos)
 }
 
 std::string
-GameSession::get_working_directory()
+GameSession::get_working_directory() const
 {
   return FileSystem::dirname(levelfile);
 }
