@@ -1,5 +1,5 @@
 //  SuperTux
-//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmx.de>
+//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmail.com>
 //
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,9 @@
 #ifndef HEADER_SUPERTUX_SUPERTUX_GLOBALS_HPP
 #define HEADER_SUPERTUX_SUPERTUX_GLOBALS_HPP
 
-typedef struct SDL_Surface SDL_Surface;
-namespace tinygettext { class DictionaryManager; }
+#include <memory>
+
 class Config;
-class JoystickKeyboardController;
-class PlayerStatus;
-class ScreenManager;
-class SoundManager;
-class SpriteManager;
-class TextureManager;
-class TileManager;
 class TileSet;
 
 /** The width of the display (this is a logical value, not the
@@ -39,30 +32,13 @@ extern int SCREEN_WIDTH;
     shrink or scale things) */
 extern int SCREEN_HEIGHT;
 
-// global variables
-extern JoystickKeyboardController* g_jk_controller;
-
-extern SDL_Surface* g_screen;
-
-extern ScreenManager* g_screen_manager;
-
-extern TextureManager* texture_manager;
-
-extern SoundManager* sound_manager;
-
-extern Config* g_config;
-
-extern tinygettext::DictionaryManager* dictionary_manager;
+extern std::unique_ptr<Config> g_config;
 
 extern float game_time;
 extern float real_time;
 
-extern TileManager *tile_manager;
-
 /** this is only set while loading a map */
-extern TileSet     *current_tileset;
-
-extern SpriteManager* sprite_manager;
+extern TileSet* current_tileset;
 
 extern float g_game_speed;
 
