@@ -1,5 +1,5 @@
 //  SuperTux
-//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmx.de>
+//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmail.com>
 //
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -25,14 +25,13 @@ class World;
 class ContribMenu : public Menu
 {
 private:
-  std::auto_ptr<ContribWorldMenu> m_contrib_world_menu;
-  std::vector<World*> m_contrib_worlds;
+  std::vector<std::unique_ptr<World> > m_contrib_worlds;
 
 public:
   ContribMenu();
   ~ContribMenu();
-  
-  void check_menu();
+
+  void menu_action(MenuItem* item) override;
 
 private:
   ContribMenu(const ContribMenu&);
