@@ -20,6 +20,7 @@
 #include <sstream>
 
 #include "control/joystick_manager.hpp"
+#include "gui/item_controlfield.hpp"
 #include "supertux/gameconfig.hpp"
 #include "util/gettext.hpp"
 
@@ -35,7 +36,8 @@ enum {
 
 JoystickMenu::JoystickMenu(InputManager& input_manager) :
   m_input_manager(input_manager),
-  m_joysticks_available(false)
+  m_joysticks_available(false),
+  m_auto_joystick_cfg(!m_input_manager.use_game_controller())
 {
   recreate_menu();
 }
@@ -51,7 +53,7 @@ JoystickMenu::recreate_menu()
   add_hl();
 
   add_toggle(MNID_AUTO_JOYSTICK_CFG, _("Manual Configuration"),
-             !m_input_manager.use_game_controller())
+             &m_auto_joystick_cfg)
     ->set_help(_("Use manual configuration instead of SDL2's automatic GameController support"));
 
   if (m_input_manager.use_game_controller())
@@ -75,19 +77,19 @@ JoystickMenu::recreate_menu()
       add_controlfield(Controller::PEEK_RIGHT,  _("Peek Right"));
       add_controlfield(Controller::PEEK_UP,     _("Peek Up"));
       add_controlfield(Controller::PEEK_DOWN,   _("Peek Down"));
-      if (g_config->developer_mode || g_config->console_enabled) {
+      if (g_config->developer_mode) {
         add_controlfield(Controller::CONSOLE, _("Console"));
       }
       if (g_config->developer_mode) {
         add_controlfield(Controller::CHEAT_MENU, _("Cheat Menu"));
       }
-      add_toggle(MNID_JUMP_WITH_UP, _("Jump with Up"), g_config->joystick_config.jump_with_up_joy);
+      add_toggle(MNID_JUMP_WITH_UP, _("Jump with Up"), &g_config->joystick_config.jump_with_up_joy);
     }
     else
     {
       m_joysticks_available = false;
 
-      add_inactive(-1, _("No Joysticks found"));
+      add_inactive(_("No Joysticks found"));
       add_entry(MNID_SCAN_JOYSTICKS, _("Scan for Joysticks"));
     }
   }
@@ -98,7 +100,7 @@ JoystickMenu::recreate_menu()
 }
 
 std::string
-JoystickMenu::get_button_name(int button)
+JoystickMenu::get_button_name(int button) const
 {
   if(button < 0)
   {
@@ -117,16 +119,17 @@ JoystickMenu::menu_action(MenuItem* item)
 {
   if (0 <= item->id && item->id < Controller::CONTROLCOUNT)
   {
-    item->change_input(_("Press Button"));
+    ItemControlField* micf = dynamic_cast<ItemControlField*>(item);
+    if (!micf) {
+      return;
+    }
+    micf->change_input(_("Press Button"));
     m_input_manager.joystick_manager->bind_next_event_to(static_cast<Controller::Control>(item->id));
   }
-  else if (item->id == MNID_JUMP_WITH_UP)
-  {
-    g_config->joystick_config.jump_with_up_joy = item->toggled;
-  }
   else if (item->id == MNID_AUTO_JOYSTICK_CFG)
   {
-    m_input_manager.use_game_controller(!item->toggled);
+    //m_input_manager.use_game_controller(!item->toggled);
+    m_input_manager.use_game_controller(!m_auto_joystick_cfg);
     m_input_manager.reset();
     recreate_menu();
   }
@@ -140,13 +143,18 @@ JoystickMenu::menu_action(MenuItem* item)
 void
 JoystickMenu::refresh_menu_item(Controller::Control id)
 {
+  ItemControlField* itemcf = dynamic_cast<ItemControlField*>(&get_item_by_id(static_cast<int>(id)));
+  if (!itemcf) {
+    return;
+  }
+
   int button  = g_config->joystick_config.reversemap_joybutton(id);
   int axis    = g_config->joystick_config.reversemap_joyaxis(id);
   int hat_dir = g_config->joystick_config.reversemap_joyhat(id);
 
   if (button != -1)
   {
-    get_item_by_id(static_cast<int>(id)).change_input(get_button_name(button));
+    itemcf->change_input(get_button_name(button));
   }
   else if (axis != 0)
   {
@@ -170,7 +178,7 @@ JoystickMenu::refresh_menu_item(Controller::Control id)
     else
       name << abs(axis);
 
-    get_item_by_id(static_cast<int>(id)).change_input(name.str());
+    itemcf->change_input(name.str());
   }
   else if (hat_dir != -1)
   {
@@ -199,11 +207,11 @@ JoystickMenu::refresh_menu_item(Controller::Control id)
         break;
     }
 
-    get_item_by_id(static_cast<int>(id)).change_input(name);
+    itemcf->change_input(name);
   }
   else
   {
-    get_item_by_id(static_cast<int>(id)).change_input("None");
+    itemcf->change_input("None");
   }
 }
 
@@ -225,7 +233,7 @@ JoystickMenu::refresh()
     refresh_menu_item(Controller::PEEK_UP);
     refresh_menu_item(Controller::PEEK_DOWN);
 
-    if (g_config->developer_mode || g_config->console_enabled) {
+    if (g_config->developer_mode) {
       refresh_menu_item(Controller::CONSOLE);
     }
     if (g_config->developer_mode) {
