@@ -27,10 +27,10 @@ public:
   JoystickMenu(InputManager& input_manager);
   virtual ~JoystickMenu();
 
-  void refresh();
+  void refresh() override;
   void refresh_menu_item(Controller::Control id);
 
-  std::string get_button_name(int button);
+  std::string get_button_name(int button) const;
   void menu_action(MenuItem* item) override;
 
 private:
@@ -39,6 +39,7 @@ private:
 private:
   InputManager& m_input_manager;
   bool m_joysticks_available;
+  bool m_auto_joystick_cfg;
 
 private:
   JoystickMenu(const JoystickMenu&);
