@@ -21,12 +21,14 @@
 #include "gui/menu_item.hpp"
 #include "gui/menu_manager.hpp"
 #include "supertux/fadeout.hpp"
+#include "supertux/gameconfig.hpp"
 #include "supertux/game_manager.hpp"
 #include "supertux/globals.hpp"
 #include "supertux/menu/addon_menu.hpp"
 #include "supertux/menu/contrib_menu.hpp"
 #include "supertux/menu/menu_storage.hpp"
 #include "supertux/menu/options_menu.hpp"
+#include "supertux/menu/world_set_menu.hpp"
 #include "supertux/screen_fade.hpp"
 #include "supertux/screen_manager.hpp"
 #include "supertux/textscroller.hpp"
@@ -39,7 +41,6 @@ MainMenu::MainMenu()
   set_center_pos(SCREEN_WIDTH/2, SCREEN_HEIGHT/2 + 35);
 
   add_entry(MNID_STARTGAME, _("Start Game"));
-  add_entry(MNID_LEVELS_CONTRIB, _("Contrib Levels"));
   add_entry(MNID_ADDONS, _("Add-ons"));
   add_submenu(_("Options"), MenuStorage::OPTIONS_MENU);
   add_entry(MNID_CREDITS, _("Credits"));
@@ -57,27 +58,29 @@ MainMenu::menu_action(MenuItem* item)
 {
   switch (item->id)
   {
+
     case MNID_STARTGAME:
-      {
-        std::unique_ptr<World> world = World::load("levels/world1");
-        GameManager::current()->start_worldmap(std::move(world));
-      }
+      // World selection menu
+      MenuManager::instance().push_menu(MenuStorage::WORLDSET_MENU);
       break;
-
-    case MNID_LEVELS_CONTRIB:
-      // Contrib Menu
-      MenuManager::instance().push_menu(MenuStorage::CONTRIB_MENU);
-      break;
-
+    
     case MNID_ADDONS:
       // Add-ons Menu
       MenuManager::instance().push_menu(MenuStorage::ADDON_MENU);
       break;
 
+
     case MNID_CREDITS:
       MenuManager::instance().clear_menu_stack();
-      ScreenManager::current()->push_screen(std::unique_ptr<Screen>(new TextScroller("credits.txt")),
-                                            std::unique_ptr<ScreenFade>(new FadeOut(0.5)));
+      if(g_config->transitions_enabled)
+      {
+        ScreenManager::current()->push_screen(std::unique_ptr<Screen>(new TextScroller("credits.txt")),
+                                                    std::unique_ptr<ScreenFade>(new FadeOut(0.5)));
+      }
+      else
+      {
+        ScreenManager::current()->push_screen(std::unique_ptr<Screen>(new TextScroller("credits.txt")));
+      }
       break;
 
     case MNID_QUITMAINMENU:
@@ -85,7 +88,14 @@ MainMenu::menu_action(MenuItem* item)
       {
         // instantly exit the game
         MenuManager::instance().clear_menu_stack();
-        ScreenManager::current()->quit(std::unique_ptr<ScreenFade>(new FadeOut(0.25)));
+        if(g_config->transitions_enabled)
+        {
+          ScreenManager::current()->quit(std::unique_ptr<ScreenFade>(new FadeOut(0.25)));
+        }
+        else
+        {
+          ScreenManager::current()->quit();
+        }
         SoundManager::current()->stop_music(0.25);
       }
       else
@@ -96,7 +106,14 @@ MainMenu::menu_action(MenuItem* item)
         dialog->add_cancel_button(_("Cancel"));
         dialog->add_default_button(_("Quit SuperTux"), [] {
             MenuManager::instance().clear_menu_stack();
-            ScreenManager::current()->quit(std::unique_ptr<ScreenFade>(new FadeOut(0.25)));
+            if(g_config->transitions_enabled)
+            {
+              ScreenManager::current()->quit(std::unique_ptr<ScreenFade>(new FadeOut(0.25)));
+            }
+            else
+            {
+              ScreenManager::current()->quit();
+            }
             SoundManager::current()->stop_music(0.25);
           });
         MenuManager::instance().set_dialog(std::move(dialog));
