@@ -29,6 +29,7 @@
 #include "supertux/menu/profile_menu.hpp"
 #include "supertux/menu/worldmap_menu.hpp"
 #include "supertux/menu/worldmap_cheat_menu.hpp"
+#include "supertux/menu/world_set_menu.hpp"
 
 MenuStorage* MenuStorage::s_instance = 0;
 
@@ -88,6 +89,9 @@ MenuStorage::create(MenuId menu_id)
     case CHEAT_MENU:
       return std::unique_ptr<Menu>(new CheatMenu);
 
+    case WORLDSET_MENU:
+      return std::unique_ptr<Menu>(new WorldSetMenu);
+      
     case CONTRIB_MENU:
       return std::unique_ptr<Menu>(new ContribMenu);
 
@@ -97,6 +101,12 @@ MenuStorage::create(MenuId menu_id)
     case ADDON_MENU:
       return std::unique_ptr<Menu>(new AddonMenu);
 
+    case LANGPACK_MENU:
+      return std::unique_ptr<Menu>(new AddonMenu(true));
+
+    case LANGPACK_AUTO_UPDATE_MENU:
+      return std::unique_ptr<Menu>(new AddonMenu(true, true));
+
     case NO_MENU:
       return std::unique_ptr<Menu>();
 
