@@ -16,6 +16,7 @@
 
 #include "supertux/menu/profile_menu.hpp"
 
+#include <boost/format.hpp>
 #include <sstream>
 
 #include "gui/menu_manager.hpp"
@@ -33,11 +34,11 @@ ProfileMenu::ProfileMenu()
     std::ostringstream out;
     if (i == g_config->profile)
     {
-      out << "[Profile " << i << "]";
+      out << str(boost::format(_("[Profile %s]")) %i);
     }
     else
     {
-      out << "Profile " << i;
+      out << str(boost::format(_("Profile %s")) %i);
     }
     add_entry(i, out.str());
   }
