@@ -1,5 +1,5 @@
 //  SuperTux
-//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmx.de>
+//  Copyright (C) 2009 Ingo Ruhnke <grumbel@gmail.com>
 //
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -16,8 +16,12 @@
 
 #include "supertux/menu/worldmap_menu.hpp"
 
+#include "gui/menu_item.hpp"
+#include "gui/menu_manager.hpp"
 #include "supertux/menu/menu_storage.hpp"
 #include "supertux/menu/options_menu.hpp"
+#include "supertux/screen_fade.hpp"
+#include "supertux/screen_manager.hpp"
 #include "util/gettext.hpp"
 
 WorldmapMenu::WorldmapMenu()
@@ -25,14 +29,25 @@ WorldmapMenu::WorldmapMenu()
   add_label(_("Pause"));
   add_hl();
   add_entry(MNID_RETURNWORLDMAP, _("Continue"));
-  add_submenu(_("Options"), MenuStorage::get_options_menu());
+  add_submenu(_("Options"), MenuStorage::INGAME_OPTIONS_MENU);
   add_hl();
   add_entry(MNID_QUITWORLDMAP, _("Quit World"));
 }
 
 void
-WorldmapMenu::check_menu()
+WorldmapMenu::menu_action(MenuItem* item)
 {
+  switch (item->id)
+  {
+    case MNID_RETURNWORLDMAP:
+      MenuManager::instance().clear_menu_stack();
+      break;
+
+    case MNID_QUITWORLDMAP:
+      MenuManager::instance().clear_menu_stack();
+      ScreenManager::current()->pop_screen();
+      break;
+  }
 }
 
 /* EOF */
