@@ -67,8 +67,8 @@ public:
   ObjectFactory();
   ~ObjectFactory();
 
-  GameObjectPtr create(const std::string& name, const Reader& reader);
-  GameObjectPtr create(const std::string& name, const Vector& pos, const Direction dir = AUTO);
+  GameObjectPtr create(const std::string& name, const Reader& reader) const;
+  GameObjectPtr create(const std::string& name, const Vector& pos, const Direction& dir = AUTO, const std::string& data = "") const;
 
 private:
   template<class C>
