@@ -19,6 +19,8 @@
 #define HEADER_SUPERTUX_SUPERTUX_RESOURCES_HPP
 
 #include "video/font_ptr.hpp"
+#include "video/surface_ptr.hpp"
+#include "supertux/tile_set.hpp"
 
 class MouseCursor;
 
@@ -32,9 +34,15 @@ public:
   static FontPtr small_font;
   static FontPtr big_font;
 
+  static SurfacePtr checkbox;
+  static SurfacePtr checkbox_checked;
+  static SurfacePtr back;
+  static SurfacePtr arrow_left;
+  static SurfacePtr arrow_right;
+
 public:
-  static void load_shared();
-  static void unload_shared();
+  Resources();
+  ~Resources();
 };
 
 #endif
