@@ -50,6 +50,7 @@
 #include "scripting/squirrel_util.hpp"
 #include "supertux/collision.hpp"
 #include "supertux/constants.hpp"
+#include "supertux/direction.hpp"
 #include "supertux/game_session.hpp"
 #include "supertux/globals.hpp"
 #include "supertux/level.hpp"
@@ -142,7 +143,7 @@ Sector::~Sector()
 }
 
 Level*
-Sector::get_level()
+Sector::get_level() const
 {
   return level;
 }
@@ -201,7 +202,9 @@ Sector::parse(const Reader& sector)
       iter.value()->get(music);
     } else if(token == "spawnpoint") {
       auto sp = std::make_shared<SpawnPoint>(*iter.lisp());
-      spawnpoints.push_back(sp);
+      if (sp->name != "" && sp->pos.x >= 0 && sp->pos.y >= 0) {
+        spawnpoints.push_back(sp);
+      }
     } else if(token == "init-script") {
       iter.value()->get(init_script);
     } else if(token == "ambient-light") {
@@ -412,36 +415,19 @@ Sector::fix_old_tiles()
     TileMap* solids = *i;
     for(size_t x=0; x < solids->get_width(); ++x) {
       for(size_t y=0; y < solids->get_height(); ++y) {
-        uint32_t    id   = solids->get_tile_id(x, y);
         const Tile *tile = solids->get_tile(x, y);
-        Vector pos = solids->get_tile_position(x, y);
 
-        if(id == 112) {
-          add_object(std::make_shared<InvisibleBlock>(pos));
-          solids->change(x, y, 0);
-        } else if(tile->getAttributes() & Tile::COIN) {
-          add_object(std::make_shared<Coin>(pos, solids));
-          solids->change(x, y, 0);
-        } else if(tile->getAttributes() & Tile::FULLBOX) {
-          add_object(std::make_shared<BonusBlock>(pos, tile->getData()));
-          solids->change(x, y, 0);
-        } else if(tile->getAttributes() & Tile::BRICK) {
-          if( ( id == 3159 ) || ( id == 3160 ) ){
-            add_object( std::make_shared<Brick>(pos, tile->getData(), "images/objects/bonus_block/brickWeb.sprite") );
-          } else if( ( id == 78 ) || ( id == 105 ) ){
-            add_object( std::make_shared<Brick>(pos, tile->getData(), "images/objects/bonus_block/brickIce.sprite") );
-          } else if( ( id == 77 ) || ( id == 104 ) ){
-            add_object( std::make_shared<Brick>(pos, tile->getData(), "images/objects/bonus_block/brick.sprite") );
-          } else {
-            log_warning << "attribute 'brick #t' is not supported for tile-id " << id << std::endl;
-            add_object( std::make_shared<Brick>(pos, tile->getData(), "images/objects/bonus_block/brick.sprite") );
+        if (tile->get_object_name().length() > 0) {
+          Vector pos = solids->get_tile_position(x, y);
+          try {
+            GameObjectPtr object = ObjectFactory::instance().create(tile->get_object_name(), pos, AUTO, tile->get_object_data());
+            add_object(object);
+            solids->change(x, y, 0);
+          } catch(std::exception& e) {
+            log_warning << e.what() << "" << std::endl;
           }
-          solids->change(x, y, 0);
-        } else if(tile->getAttributes() & Tile::GOAL) {
-          std::string sequence = tile->getData() == 0 ? "endsequence" : "stoptux";
-          add_object(std::make_shared<SequenceTrigger>(pos, sequence));
-          solids->change(x, y, 0);
         }
+
       }
     }
   }
@@ -452,23 +438,24 @@ Sector::fix_old_tiles()
     if (!tm) continue;
     for(size_t x=0; x < tm->get_width(); ++x) {
       for(size_t y=0; y < tm->get_height(); ++y) {
-        uint32_t id = tm->get_tile_id(x, y);
+        const Tile* tile = tm->get_tile(x, y);
+        uint32_t attributes = tile->getAttributes();
         Vector pos = tm->get_tile_position(x, y);
         Vector center = pos + Vector(16, 16);
 
-        // torch
-        if (id == 1517) {
-          float pseudo_rnd = (float)((int)pos.x % 10) / 10;
-          add_object(std::make_shared<PulsingLight>(center, 1.0f + pseudo_rnd, 0.9f, 1.0f, Color(1.0f, 1.0f, 0.6f, 1.0f)));
-        }
-        // lava or lavaflow
-        if ((id == 173) || (id == 1700) || (id == 1705) || (id == 1706)) {
-          // space lights a bit
-          if ((((tm->get_tile_id(x-1, y)) != tm->get_tile_id(x,y))
-               && (tm->get_tile_id(x, y-1) != tm->get_tile_id(x,y)))
-              || ((x % 3 == 0) && (y % 3 == 0))) {
+        if (attributes & Tile::FIRE) {
+          if (attributes & Tile::HURTS) {
+            // lava or lavaflow
+            // space lights a bit
+            if ((tm->get_tile(x-1, y)->getAttributes() != attributes || x%3 == 0)
+                 && (tm->get_tile(x, y-1)->getAttributes() != attributes || y%3 == 0)) {
+              float pseudo_rnd = (float)((int)pos.x % 10) / 10;
+              add_object(std::make_shared<PulsingLight>(center, 1.0f + pseudo_rnd, 0.8f, 1.0f, Color(1.0f, 0.3f, 0.0f, 1.0f)));
+            }
+          } else {
+            // torch
             float pseudo_rnd = (float)((int)pos.x % 10) / 10;
-            add_object(std::make_shared<PulsingLight>(center, 1.0f + pseudo_rnd, 0.8f, 1.0f, Color(1.0f, 0.3f, 0.0f, 1.0f)));
+            add_object(std::make_shared<PulsingLight>(center, 1.0f + pseudo_rnd, 0.9f, 1.0f, Color(1.0f, 1.0f, 0.6f, 1.0f)));
           }
         }
 
@@ -656,7 +643,7 @@ Sector::deactivate()
 }
 
 Rectf
-Sector::get_active_region()
+Sector::get_active_region() const
 {
   return Rectf(
     camera->get_translation() - Vector(1600, 1200),
@@ -664,7 +651,7 @@ Sector::get_active_region()
 }
 
 int
-Sector::calculate_foremost_layer()
+Sector::calculate_foremost_layer() const
 {
   int layer = LAYER_BACKGROUND0;
   for(auto i = gameobjects.begin(); i != gameobjects.end(); ++i)
@@ -688,7 +675,7 @@ Sector::calculate_foremost_layer()
 }
 
 int
-Sector::get_foremost_layer()
+Sector::get_foremost_layer() const
 {
   return foremost_layer;
 }
@@ -936,9 +923,9 @@ void check_collisions(collision::Constraints* constraints,
 
   MovingObject *moving_object = dynamic_cast<MovingObject*> (object);
   CollisionHit dummy;
-  if(other != NULL && !other->collides(*object, dummy))
+  if(other != NULL && object != NULL && !other->collides(*object, dummy))
     return;
-  if(moving_object != NULL && !moving_object->collides(*other, dummy))
+  if(moving_object != NULL && other != NULL && !moving_object->collides(*other, dummy))
     return;
 
   // calculate intersection
@@ -967,14 +954,14 @@ void check_collisions(collision::Constraints* constraints,
   }
 
   constraints->ground_movement += other_movement;
-  if(other != NULL) {
+  if(other != NULL && object != NULL) {
     HitResponse response = other->collision(*object, dummy);
     if(response == ABORT_MOVE)
       return;
 
     if(other->get_movement() != Vector(0, 0)) {
       // TODO what todo when we collide with 2 moving objects?!?
-      constraints->ground_movement = other->get_movement();
+      constraints->ground_movement += other->get_movement();
     }
   }
 
@@ -1057,7 +1044,7 @@ Sector::collision_tilemap(collision::Constraints* constraints,
 }
 
 uint32_t
-Sector::collision_tile_attributes(const Rectf& dest) const
+Sector::collision_tile_attributes(const Rectf& dest, const Vector& mov) const
 {
   float x1 = dest.p1.x;
   float y1 = dest.p1.y;
@@ -1079,13 +1066,17 @@ Sector::collision_tile_attributes(const Rectf& dest) const
         const Tile* tile = solids->get_tile(x, y);
         if(!tile)
           continue;
-        result |= tile->getAttributes();
+        if ( tile->is_collisionful( solids->get_tile_bbox(x, y), dest, mov) ) {
+          result |= tile->getAttributes();
+        }
       }
       for(; y < test_tiles_ice.bottom; ++y) {
         const Tile* tile = solids->get_tile(x, y);
         if(!tile)
           continue;
-        result |= (tile->getAttributes() & Tile::ICE);
+        if ( tile->is_collisionful( solids->get_tile_bbox(x, y), dest, mov) ) {
+          result |= (tile->getAttributes() & Tile::ICE);
+        }
       }
     }
   }
@@ -1193,6 +1184,7 @@ Sector::collision_static_constrains(MovingObject& object)
 
   Constraints constraints;
   Vector movement = object.get_movement();
+  Vector pressure = Vector(0,0);
   Rectf& dest = object.dest;
 
   for(int i = 0; i < 2; ++i) {
@@ -1207,9 +1199,11 @@ Sector::collision_static_constrains(MovingObject& object)
         // we're crushed, but ignore this for now, we'll get this again
         // later if we're really crushed or things will solve itself when
         // looking at the vertical constraints
+        pressure.y += object.get_bbox().get_height() - height;
+      } else {
+        dest.p2.y = constraints.get_position_bottom() - DELTA;
+        dest.p1.y = dest.p2.y - object.get_bbox().get_height();
       }
-      dest.p2.y = constraints.get_position_bottom() - DELTA;
-      dest.p1.y = dest.p2.y - object.get_bbox().get_height();
     } else if(constraints.get_position_top() > -infinity) {
       dest.p1.y = constraints.get_position_top() + DELTA;
       dest.p2.y = dest.p1.y + object.get_bbox().get_height();
@@ -1236,15 +1230,10 @@ Sector::collision_static_constrains(MovingObject& object)
     float width = constraints.get_width ();
     if(width < infinity) {
       if(width + SHIFT_DELTA < object.get_bbox().get_width()) {
-#if 0
-        printf("Object %p crushed horizontally... L:%f R:%f\n", &object,
-               constraints.get_position_left(), constraints.get_position_right());
-#endif
-        CollisionHit h;
-        h.left = true;
-        h.right = true;
-        h.crush = true;
-        object.collision_solid(h);
+        // we're crushed, but ignore this for now, we'll get this again
+        // later if we're really crushed or things will solve itself when
+        // looking at the horizontal constraints
+        pressure.x += object.get_bbox().get_width() - width;
       } else {
         float xmid = constraints.get_x_midpoint ();
         dest.p1.x = xmid - object.get_bbox().get_width()/2;
@@ -1266,20 +1255,37 @@ Sector::collision_static_constrains(MovingObject& object)
       object.collision_solid(constraints.hit);
   }
 
+  // an extra pass to make sure we're not crushed vertically
+  if (pressure.y > 0) {
+    constraints = Constraints();
+    collision_static(&constraints, movement, dest, object);
+    if(constraints.get_position_bottom() < infinity) {
+      float height = constraints.get_height ();
+      if(height + SHIFT_DELTA < object.get_bbox().get_height()) {
+        CollisionHit h;
+        h.top = true;
+        h.bottom = true;
+        h.crush = pressure.y > 16;
+        object.collision_solid(h);
+      }
+    }
+  }
+
   // an extra pass to make sure we're not crushed horizontally
-  constraints = Constraints();
-  collision_static(&constraints, movement, dest, object);
-  if(constraints.get_position_bottom() < infinity) {
-    float height = constraints.get_height ();
-    if(height + SHIFT_DELTA < object.get_bbox().get_height()) {
-#if 0
-      printf("Object %p crushed vertically...\n", &object);
-#endif
-      CollisionHit h;
-      h.top = true;
-      h.bottom = true;
-      h.crush = true;
-      object.collision_solid(h);
+  if (pressure.x > 0) {
+    constraints = Constraints();
+    collision_static(&constraints, movement, dest, object);
+    if(constraints.get_position_right() < infinity) {
+      float width = constraints.get_width ();
+      if(width + SHIFT_DELTA < object.get_bbox().get_width()) {
+        CollisionHit h;
+        h.top = true;
+        h.bottom = true;
+        h.left = true;
+        h.right = true;
+        h.crush = pressure.x > 16;
+        object.collision_solid(h);
+      }
     }
   }
 }
@@ -1329,7 +1335,7 @@ Sector::handle_collisions()
        || !moving_object->is_valid())
       continue;
 
-    uint32_t tile_attributes = collision_tile_attributes(moving_object->dest);
+    uint32_t tile_attributes = collision_tile_attributes(moving_object->dest, moving_object->get_movement());
     if(tile_attributes >= Tile::FIRST_INTERESTING_FLAG) {
       moving_object->collision_tile(tile_attributes);
     }
@@ -1470,6 +1476,61 @@ Sector::is_free_of_movingstatics(const Rectf& rect, const MovingObject* ignore_o
   return true;
 }
 
+bool
+Sector::free_line_of_sight(const Vector& line_start, const Vector& line_end, const MovingObject* ignore_object) const
+{
+  using namespace collision;
+
+  // check if no tile is in the way
+  float lsx = std::min(line_start.x, line_end.x);
+  float lex = std::max(line_start.x, line_end.x);
+  float lsy = std::min(line_start.y, line_end.y);
+  float ley = std::max(line_start.y, line_end.y);
+  for (float test_x = lsx; test_x <= lex; test_x += 16) {
+    for (float test_y = lsy; test_y <= ley; test_y += 16) {
+      for(auto i = solid_tilemaps.begin(); i != solid_tilemaps.end(); ++i) {
+        TileMap* solids = *i;
+        const Tile* tile = solids->get_tile_at(Vector(test_x, test_y));
+        if(!tile) continue;
+        // FIXME: check collision with slope tiles
+        if((tile->getAttributes() & Tile::SOLID)) return false;
+      }
+    }
+  }
+
+  // check if no object is in the way
+  for(auto i = moving_objects.begin(); i != moving_objects.end(); ++i) {
+    const MovingObject* moving_object = *i;
+    if (moving_object == ignore_object) continue;
+    if (!moving_object->is_valid()) continue;
+    if ((moving_object->get_group() == COLGROUP_MOVING)
+        || (moving_object->get_group() == COLGROUP_MOVING_STATIC)
+        || (moving_object->get_group() == COLGROUP_STATIC)) {
+      if(intersects_line(moving_object->get_bbox(), line_start, line_end)) return false;
+    }
+  }
+
+  return true;
+}
+
+bool
+Sector::can_see_player(const Vector& eye) const
+{
+    const std::vector<Player*> players = get_players();
+    for (auto playerIter = players.begin(); playerIter != players.end(); ++playerIter) {
+      Player* pl = *playerIter;
+
+      // test for free line of sight to any of all four corners and the middle of the player's bounding box
+      if (free_line_of_sight(eye, pl->get_bbox().p1, pl)) return true;
+      if (free_line_of_sight(eye, Vector(pl->get_bbox().p2.x, pl->get_bbox().p1.y), pl)) return true;
+      if (free_line_of_sight(eye, pl->get_bbox().p2, pl)) return true;
+      if (free_line_of_sight(eye, Vector(pl->get_bbox().p1.x, pl->get_bbox().p2.y), pl)) return true;
+      if (free_line_of_sight(eye, pl->get_bbox().get_middle(), pl)) return true;
+    }
+    return false;
+}
+
+
 bool
 Sector::add_smoke_cloud(const Vector& pos)
 {
@@ -1512,13 +1573,13 @@ Sector::resume_music()
 }
 
 MusicType
-Sector::get_music_type()
+Sector::get_music_type() const
 {
   return currentmusic;
 }
 
 int
-Sector::get_total_badguys()
+Sector::get_total_badguys() const
 {
   int total_badguys = 0;
   for(auto i = gameobjects.begin(); i != gameobjects.end(); ++i) {
@@ -1619,12 +1680,12 @@ Sector::get_gravity() const
 }
 
 Player*
-Sector::get_nearest_player (const Vector& pos)
+Sector::get_nearest_player (const Vector& pos) const
 {
   Player *nearest_player = NULL;
   float nearest_dist = std::numeric_limits<float>::max();
 
-  std::vector<Player*> players = Sector::current()->get_players();
+  std::vector<Player*> players = get_players();
   for (auto playerIter = players.begin(); playerIter != players.end(); ++playerIter)
   {
     Player *this_player = *playerIter;
@@ -1643,7 +1704,7 @@ Sector::get_nearest_player (const Vector& pos)
 } /* Player *get_nearest_player */
 
 std::vector<MovingObject*>
-Sector::get_nearby_objects (const Vector& center, float max_distance)
+Sector::get_nearby_objects (const Vector& center, float max_distance) const
 {
   std::vector<MovingObject*> ret;
   std::vector<Player*> players = Sector::current()->get_players();
