@@ -18,16 +18,18 @@
 #define HEADER_SUPERTUX_SUPERTUX_TILE_MANAGER_HPP
 
 #include <map>
+#include <memory>
 #include <string>
 
+#include "util/currenton.hpp"
 #include "util/reader_fwd.hpp"
 
 class TileSet;
 
-class TileManager
+class TileManager : public Currenton<TileManager>
 {
 private:
-  typedef std::map<std::string, TileSet*> TileSets;
+  typedef std::map<std::string, std::unique_ptr<TileSet> > TileSets;
   TileSets tilesets;
 
 public:
@@ -36,7 +38,7 @@ public:
 
   TileSet* get_tileset(const std::string &filename);
 
-  TileSet* parse_tileset_definition(const Reader& reader);
+  std::unique_ptr<TileSet> parse_tileset_definition(const Reader& reader);
 };
 
 #endif
