@@ -120,6 +120,10 @@ TileSetParser::parse_tile(const Reader& reader)
   float fps = 10;
   reader.get("fps", fps);
 
+  std::string object_name, object_data;
+  reader.get("object-name", object_name);
+  reader.get("object-data", object_data);
+
   if(reader.get("slope-type", data))
   {
     attributes |= Tile::SOLID | Tile::SLOPE;
@@ -137,7 +141,8 @@ TileSetParser::parse_tile(const Reader& reader)
   if(images)
       imagespecs = parse_tile_images(*images);
 
-  std::unique_ptr<Tile> tile(new Tile(imagespecs, editor_imagespecs, attributes, data, fps));
+  std::unique_ptr<Tile> tile(new Tile(imagespecs, editor_imagespecs, attributes, data, fps,
+                                      object_name, object_data));
 
   if (id >= m_tileset.tiles.size())
     m_tileset.tiles.resize(id+1, 0);
@@ -223,7 +228,7 @@ TileSetParser::parse_tiles(const Reader& reader)
   unsigned int width  = 0;
   unsigned int height = 0;
 
-  reader.get("ids",        ids);
+  bool has_ids = reader.get("ids",        ids);
   bool has_attributes = reader.get("attributes", attributes);
   bool has_datas = reader.get("datas", datas);
 
@@ -241,6 +246,10 @@ TileSetParser::parse_tiles(const Reader& reader)
   float fps = 10;
   reader.get("fps",     fps);
 
+  if (ids.empty() || !has_ids)
+  {
+    throw std::runtime_error("No IDs specified.");
+  }
   if (width == 0)
   {
     throw std::runtime_error("Width is zero.");
