@@ -19,6 +19,7 @@
 
 #include "trigger/trigger_base.hpp"
 
+#include "object/tilemap.hpp"
 #include "supertux/timer.hpp"
 #include "util/reader_fwd.hpp"
 #include "util/writer_fwd.hpp"
@@ -36,12 +37,14 @@ public:
 
   void event(Player& player, EventType type);
   void draw(DrawingContext& context);
+  std::string get_fade_tilemap_name();
 
 private:
   Timer message_timer;
   bool message_displayed;
-  std::string message; /**< message to display, default "You found a secret area!" */ 
+  std::string message; /**< message to display, default "You found a secret area!" */
   std::string fade_tilemap; /**< tilemap to fade away when trigger is activated, or empty if you don't care */
+  std::string script; /**< optional script to run when trigger is activated */
 };
 
 #endif
