@@ -46,7 +46,9 @@ private:
   std::string sprite_name;
   SpritePtr sprite;
   std::string script;
+  std::string off_script;
   SwitchState state;
+  bool bistable;
 };
 
 #endif
