@@ -21,6 +21,8 @@
 
 #include "math/rectf.hpp"
 #include "supertux/console.hpp"
+#include "supertux/gameconfig.hpp"
+#include "supertux/globals.hpp"
 
 LogLevel g_log_level = LOG_WARNING;
 
@@ -50,11 +52,19 @@ std::ostream& log_info_f(const char* file, int line)
 
 std::ostream& log_warning_f(const char* file, int line)
 {
+  if(g_config && g_config->developer_mode &&
+     Console::current() && !Console::current()->hasFocus()) {
+    Console::current()->open();
+  }
   return (log_generic_f ("[WARNING]", file, line));
 }
 
 std::ostream& log_fatal_f(const char* file, int line)
 {
+  if(g_config && g_config->developer_mode &&
+     Console::current() && !Console::current()->hasFocus()) {
+    Console::current()->open();
+  }
   return (log_generic_f ("[FATAL]", file, line));
 }
 
@@ -71,4 +81,20 @@ std::ostream& operator<<(std::ostream& out, const Rectf& rect)
   return out;
 }
 
+/* Callbacks used by tinygettext */
+void log_info_callback(const std::string& str)
+{
+    log_info << "\r\n[TINYGETTEXT] " << str << std::endl;
+}
+
+void log_warning_callback(const std::string& str)
+{
+    log_debug << "\r\n[TINYGETTEXT] " << str << std::endl;
+}
+
+void log_error_callback(const std::string& str)
+{
+    log_warning << "\r\n[TINYGETTEXT] " << str << std::endl;
+}
+
 /* EOF */
