@@ -97,13 +97,15 @@ struct GradientRequest : public DrawingRequestData
     top(),
     bottom(),
     size(),
-    direction()
+    direction(),
+    region()
   {}
 
   Color top;
   Color bottom;
   Vector size;
   GradientDirection direction;
+  Rectf region;
 };
 
 struct FillRectRequest : public DrawingRequestData
