@@ -29,26 +29,25 @@ public:
   GLLightmap();
   ~GLLightmap();
 
-  void start_draw(const Color &ambient_color);
-  void end_draw();
-  void do_draw();
-  void draw_surface(const DrawingRequest& request);
-  void draw_surface_part(const DrawingRequest& request);
-  void draw_text(const DrawingRequest& request);
-  void draw_gradient(const DrawingRequest& request);
-  void draw_filled_rect(const DrawingRequest& request);
-  void get_light(const DrawingRequest& request) const;
+  void start_draw(const Color &ambient_color) override;
+  void end_draw() override;
+  void do_draw() override;
+  void draw_surface(const DrawingRequest& request) override;
+  void draw_surface_part(const DrawingRequest& request) override;
+  void draw_gradient(const DrawingRequest& request) override;
+  void draw_filled_rect(const DrawingRequest& request) override;
+  void draw_inverse_ellipse(const DrawingRequest& request) override;
+  void get_light(const DrawingRequest& request) const override;
 
 private:
-  static const int LIGHTMAP_DIV = 5;
+  static const int s_LIGHTMAP_DIV = 5;
 
-  SDL_Surface* screen;
-  boost::shared_ptr<GLTexture> lightmap;
-  int lightmap_width;
-  int lightmap_height;
-  float lightmap_uv_right;
-  float lightmap_uv_bottom;
-  GLfloat old_viewport[4]; //holds vieport before redefining in start_draw - returned from glGet
+  std::shared_ptr<GLTexture> m_lightmap;
+  int m_lightmap_width;
+  int m_lightmap_height;
+  float m_lightmap_uv_right;
+  float m_lightmap_uv_bottom;
+  GLfloat m_old_viewport[4]; //holds vieport before redefining in start_draw - returned from glGet
 
 private:
   GLLightmap(const GLLightmap&);
