@@ -40,7 +40,7 @@ public:
   Vector to_logical(int physical_x, int physical_y) override;
   void set_gamma(float gamma) override;
 
-  SDL_Window* get_window() const { return m_window; }
+  SDL_Window* get_window() const override { return m_window; }
   SDL_Renderer* get_sdl_renderer() const { return m_renderer; };
 
 private:
