@@ -55,6 +55,7 @@
 #include "supertux/savegame.hpp"
 #include "supertux/screen_manager.hpp"
 #include "supertux/sector.hpp"
+#include "supertux/fadein.hpp"
 #include "supertux/shrinkfade.hpp"
 #include "supertux/spawn_point.hpp"
 #include "supertux/textscroller.hpp"
@@ -106,8 +107,7 @@ WorldMap::WorldMap(const std::string& filename, Savegame& savegame, const std::s
   force_spawnpoint(force_spawnpoint_),
   in_level(false),
   pan_pos(),
-  panning(false),
-  last_position()
+  panning(false)
 {
   tux = std::make_shared<Tux>(this);
   add_object(tux);
@@ -295,6 +295,7 @@ WorldMap::load(const std::string& filename)
         spawn_points.push_back(sp);
       } else if(iter.item() == "level") {
         auto level = std::make_shared<LevelTile>(levels_path, *iter.lisp());
+        load_level_information(*level.get());
         levels.push_back(level.get());
         add_object(level);
       } else if(iter.item() == "special-tile") {
@@ -344,14 +345,8 @@ WorldMap::load(const std::string& filename)
 void
 WorldMap::load_level_information(LevelTile& level)
 {
-  if(last_position == tux->get_tile_pos())
-  {
-    return;
-  }
-
-  last_position = tux->get_tile_pos();
   /** get special_tile's title */
-  level.title = "<no title>";
+  level.title = _("<no title>");
   level.target_time = 0.0f;
 
   try {
@@ -395,7 +390,7 @@ WorldMap::on_escape_press()
 }
 
 Vector
-WorldMap::get_next_tile(Vector pos, Direction direction)
+WorldMap::get_next_tile(Vector pos, const Direction& direction) const
 {
   switch(direction) {
     case D_WEST:
@@ -417,7 +412,7 @@ WorldMap::get_next_tile(Vector pos, Direction direction)
 }
 
 bool
-WorldMap::path_ok(Direction direction, const Vector& old_pos, Vector* new_pos)
+WorldMap::path_ok(const Direction& direction, const Vector& old_pos, Vector* new_pos) const
 {
   *new_pos = get_next_tile(old_pos, direction);
 
@@ -472,8 +467,6 @@ WorldMap::finished_level(Level* gamelevel)
   // deal with statistics
   level->statistics.merge(gamelevel->stats);
   calculate_total_stats();
-  if (level->target_time == 0.0f)
-    load_level_information(*level);
 
   if(level->statistics.completed(level->statistics, level->target_time)) {
     level->perfect = true;
@@ -525,7 +518,7 @@ WorldMap::finished_level(Level* gamelevel)
 }
 
 Vector
-WorldMap::get_camera_pos_for_tux() {
+WorldMap::get_camera_pos_for_tux() const {
   Vector camera_offset_;
   Vector tux_pos = tux->get_pos();
   camera_offset_.x = tux_pos.x - SCREEN_WIDTH/2;
@@ -683,9 +676,15 @@ WorldMap::update(float delta)
 
           // update state and savegame
           save_state();
-
-          ScreenManager::current()->push_screen(std::unique_ptr<Screen>(new GameSession(levelfile, m_savegame, &level_->statistics)),
-                                        std::unique_ptr<ScreenFade>(new ShrinkFade(shrinkpos, 1.0f)));
+          if(g_config->transitions_enabled)
+          {
+            ScreenManager::current()->push_screen(std::unique_ptr<Screen>(new GameSession(levelfile, m_savegame, &level_->statistics)),
+                                          std::unique_ptr<ScreenFade>(new ShrinkFade(shrinkpos, 1.0f)));
+          }
+          else
+          {
+            ScreenManager::current()->push_screen(std::unique_ptr<Screen>(new GameSession(levelfile, m_savegame, &level_->statistics)));
+          }
           in_level = true;
         } catch(std::exception& e) {
           log_fatal << "Couldn't load level: " << e.what() << std::endl;
@@ -700,7 +699,7 @@ WorldMap::update(float delta)
 }
 
 int
-WorldMap::tile_data_at(Vector p)
+WorldMap::tile_data_at(const Vector& p) const
 {
   int dirs = 0;
 
@@ -715,15 +714,15 @@ WorldMap::tile_data_at(Vector p)
 }
 
 int
-WorldMap::available_directions_at(Vector p)
+WorldMap::available_directions_at(const Vector& p) const
 {
   return tile_data_at(p) & Tile::WORLDMAP_DIR_MASK;
 }
 
 LevelTile*
-WorldMap::at_level()
+WorldMap::at_level() const
 {
-  for(LevelTiles::iterator i = levels.begin(); i != levels.end(); ++i) {
+  for(LevelTiles::const_iterator i = levels.begin(); i != levels.end(); ++i) {
     LevelTile* level = *i;
     if (level->pos == tux->get_tile_pos())
       return level;
@@ -733,9 +732,9 @@ WorldMap::at_level()
 }
 
 SpecialTile*
-WorldMap::at_special_tile()
+WorldMap::at_special_tile() const
 {
-  for(SpecialTiles::iterator i = special_tiles.begin();
+  for(SpecialTiles::const_iterator i = special_tiles.begin();
       i != special_tiles.end(); ++i) {
     SpecialTile* special_tile = *i;
     if (special_tile->pos == tux->get_tile_pos())
@@ -746,9 +745,9 @@ WorldMap::at_special_tile()
 }
 
 SpriteChange*
-WorldMap::at_sprite_change(const Vector& pos)
+WorldMap::at_sprite_change(const Vector& pos) const
 {
-  for(SpriteChanges::iterator i = sprite_changes.begin();
+  for(SpriteChanges::const_iterator i = sprite_changes.begin();
       i != sprite_changes.end(); ++i) {
     SpriteChange* sprite_change = *i;
     if(sprite_change->pos == pos)
@@ -759,9 +758,9 @@ WorldMap::at_sprite_change(const Vector& pos)
 }
 
 Teleporter*
-WorldMap::at_teleporter(const Vector& pos)
+WorldMap::at_teleporter(const Vector& pos) const
 {
-  for(std::vector<Teleporter*>::iterator i = teleporters.begin(); i != teleporters.end(); ++i) {
+  for(std::vector<Teleporter*>::const_iterator i = teleporters.begin(); i != teleporters.end(); ++i) {
     Teleporter* teleporter = *i;
     if(teleporter->pos == pos) return teleporter;
   }
@@ -826,9 +825,6 @@ WorldMap::draw_status(DrawingContext& context)
       LevelTile* level = *i;
 
       if (level->pos == tux->get_tile_pos()) {
-        if(level->title == "")
-          load_level_information(*level);
-
         context.draw_text(Resources::normal_font, level->title,
                           Vector(SCREEN_WIDTH/2,
                                  SCREEN_HEIGHT - Resources::normal_font->get_height() - 10),
@@ -846,9 +842,6 @@ WorldMap::draw_status(DrawingContext& context)
           }
           }
         */
-
-        if (level->target_time == 0.0f)
-          load_level_information(*level);
         level->statistics.draw_worldmap_info(context, level->target_time);
         break;
       }
@@ -892,6 +885,10 @@ WorldMap::setup()
 {
   SoundManager::current()->play_music(music);
   MenuManager::instance().clear_menu_stack();
+  if(g_config->transitions_enabled)
+  {
+    ScreenManager::current()->set_screen_fade(std::unique_ptr<ScreenFade>(new FadeIn(1)));
+  }
 
   current_ = this;
   load_state();
@@ -966,22 +963,8 @@ WorldMap::save_state()
   try {
     // get state table
     sq_pushroottable(vm);
-    sq_pushstring(vm, "state", -1);
-    if(SQ_FAILED(sq_get(vm, -2)))
-      throw scripting::SquirrelError(vm, "Couldn't get state table");
-
-    // get or create worlds table
-    sq_pushstring(vm, "worlds", -1);
-    if(SQ_FAILED(sq_get(vm, -2))) {
-      sq_pushstring(vm, "worlds", -1);
-      sq_newtable(vm);
-      if(SQ_FAILED(sq_createslot(vm, -3)))
-        throw scripting::SquirrelError(vm, "Couldn't create state.worlds");
-
-      sq_pushstring(vm, "worlds", -1);
-      if(SQ_FAILED(sq_get(vm, -2)))
-        throw scripting::SquirrelError(vm, "Couldn't create.get state.worlds");
-    }
+    get_table_entry(vm, "state");
+    get_or_create_table_entry(vm, "worlds");
 
     sq_pushstring(vm, map_filename.c_str(), map_filename.length());
     if(SQ_FAILED(sq_deleteslot(vm, -2, SQFalse)))
@@ -1000,7 +983,10 @@ WorldMap::save_state()
     store_float(vm, "y", tux->get_tile_pos().y);
     store_string(vm, "back", direction_to_string(tux->back_direction));
 
-    sq_createslot(vm, -3);
+    if(SQ_FAILED(sq_createslot(vm, -3)))
+    {
+      throw std::runtime_error("failed to create '" + name + "' table entry");
+    }
 
     // levels...
     sq_pushstring(vm, "levels", -1);
@@ -1047,6 +1033,8 @@ WorldMap::save_state()
 void
 WorldMap::load_state()
 {
+  log_debug << "loading worldmap state" << std::endl;
+
   using namespace scripting;
 
   HSQUIRRELVM vm = global_vm;
@@ -1055,25 +1043,12 @@ WorldMap::load_state()
   try {
     // get state table
     sq_pushroottable(vm);
-    sq_pushstring(vm, "state", -1);
-    if(SQ_FAILED(sq_get(vm, -2)))
-      throw scripting::SquirrelError(vm, "Couldn't get state table");
-
-    // get worlds table
-    sq_pushstring(vm, "worlds", -1);
-    if(SQ_FAILED(sq_get(vm, -2)))
-      throw scripting::SquirrelError(vm, "Couldn't get state.worlds");
-
-    // get table for our world
-    sq_pushstring(vm, map_filename.c_str(), map_filename.length());
-    if(SQ_FAILED(sq_get(vm, -2)))
-      throw scripting::SquirrelError(vm, "Couldn't get state.worlds.mapfilename");
+    get_table_entry(vm, "state");
+    get_table_entry(vm, "worlds");
+    get_table_entry(vm, map_filename);
 
     // load tux
-    sq_pushstring(vm, "tux", -1);
-    if(SQ_FAILED(sq_get(vm, -2)))
-      throw scripting::SquirrelError(vm, "Couldn't get tux");
-
+    get_table_entry(vm, "tux");
     Vector p;
     p.x = read_float(vm, "x");
     p.y = read_float(vm, "y");
@@ -1081,29 +1056,29 @@ WorldMap::load_state()
     tux->back_direction = string_to_direction(back_str);
     tux->set_tile_pos(p);
 
+    int tile_data = tile_data_at(p);
+    if(!( tile_data & ( Tile::WORLDMAP_NORTH | Tile::WORLDMAP_SOUTH | Tile::WORLDMAP_WEST | Tile::WORLDMAP_EAST ))) {
+      log_warning << "Player at illegal position " << p.x << ", " << p.y << " respawning." << std::endl;
+      move_to_spawnpoint("main");
+    }
+
     sq_pop(vm, 1);
 
     // load levels
-    sq_pushstring(vm, "levels", -1);
-    if(SQ_FAILED(sq_get(vm, -2)))
-      throw scripting::SquirrelError(vm, "Couldn't get levels");
-
+    get_table_entry(vm, "levels");
     for(LevelTiles::iterator i = levels.begin(); i != levels.end(); ++i) {
       LevelTile* level = *i;
       sq_pushstring(vm, level->get_name().c_str(), -1);
       if(SQ_SUCCEEDED(sq_get(vm, -2))) {
         level->solved = read_bool(vm, "solved");
         level->perfect = read_bool(vm, "perfect");
-        if(!level->solved)
-          level->sprite->set_action("default");
-        else
-          level->sprite->set_action((level->sprite->has_action("perfect") && level->perfect) ? "perfect" : "solved");
+        level->update_sprite_action();
         level->statistics.unserialize_from_squirrel(vm);
         sq_pop(vm, 1);
       }
     }
 
-    // leave state table
+    // leave levels table
     sq_pop(vm, 1);
 
     // load overall statistics
@@ -1111,6 +1086,8 @@ WorldMap::load_state()
 
   } catch(std::exception& e) {
     log_debug << "Not loading worldmap state: " << e.what() << std::endl;
+    save_state(); // make new initial save
+    move_to_spawnpoint("main"); // set tux to main spawnpoint
   }
   sq_settop(vm, oldtop);
 
@@ -1124,10 +1101,10 @@ WorldMap::level_count() const
 }
 
 size_t
-WorldMap::solved_level_count()
+WorldMap::solved_level_count() const
 {
   size_t count = 0;
-  for(LevelTiles::iterator i = levels.begin(); i != levels.end(); ++i) {
+  for(LevelTiles::const_iterator i = levels.begin(); i != levels.end(); ++i) {
     LevelTile* level = *i;
 
     if(level->solved)
